Class: Magick::ImageList::Montage
- Inherits:
-
Object
- Object
- Magick::ImageList::Montage
- Defined in:
- ext/RMagick/rmmain.cpp
Instance Method Summary collapse
-
#background_color=(color) ⇒ Magick::Pixel, String
Set background_color value.
- #border_color=(color) ⇒ Object
- #border_width=(width) ⇒ Object
- #compose=(compose) ⇒ Object
- #filename=(filename) ⇒ Object
- #fill=(color) ⇒ Object
- #font=(font) ⇒ Object
- #frame=(frame_arg) ⇒ Object
- #freeze ⇒ Object
- #geometry=(geometry_arg) ⇒ Object
- #gravity=(gravity) ⇒ Object
- #initialize ⇒ Object constructor
- #matte_color=(color) ⇒ Object
- #pointsize=(size) ⇒ Object
- #shadow=(shadow) ⇒ Object
- #stroke=(color) ⇒ Object
- #texture=(texture) ⇒ Object
- #tile=(tile_arg) ⇒ Object
- #title=(title) ⇒ Object
Constructor Details
#initialize ⇒ Object
305 306 307 308 309 310 |
# File 'ext/RMagick/rmmontage.cpp', line 305
VALUE
Montage_initialize(VALUE self)
{
// Nothing to do!
return self;
}
|
Instance Method Details
#background_color=(color) ⇒ Magick::Pixel, String
Set background_color value.
116 117 118 119 120 121 122 123 124 |
# File 'ext/RMagick/rmmontage.cpp', line 116
VALUE
Montage_background_color_eq(VALUE self, VALUE color)
{
Montage *montage;
TypedData_Get_Struct(self, Montage, &rm_montage_data_type, montage);
Color_to_PixelColor(&montage->info->background_color, color);
return color;
}
|
#border_color=(color) ⇒ Object
133 134 135 136 137 138 139 140 141 |
# File 'ext/RMagick/rmmontage.cpp', line 133
VALUE
Montage_border_color_eq(VALUE self, VALUE color)
{
Montage *montage;
TypedData_Get_Struct(self, Montage, &rm_montage_data_type, montage);
Color_to_PixelColor(&montage->info->border_color, color);
return color;
}
|
#border_width=(width) ⇒ Object
150 151 152 153 154 155 156 157 158 |
# File 'ext/RMagick/rmmontage.cpp', line 150
VALUE
Montage_border_width_eq(VALUE self, VALUE width)
{
Montage *montage;
TypedData_Get_Struct(self, Montage, &rm_montage_data_type, montage);
montage->info->border_width = NUM2ULONG(width);
return width;
}
|
#compose=(compose) ⇒ Object
167 168 169 170 171 172 173 174 175 |
# File 'ext/RMagick/rmmontage.cpp', line 167
VALUE
Montage_compose_eq(VALUE self, VALUE compose)
{
Montage *montage;
TypedData_Get_Struct(self, Montage, &rm_montage_data_type, montage);
VALUE_TO_ENUM(compose, montage->compose, CompositeOperator);
return compose;
}
|
#filename=(filename) ⇒ Object
184 185 186 187 188 189 190 191 192 |
# File 'ext/RMagick/rmmontage.cpp', line 184
VALUE
Montage_filename_eq(VALUE self, VALUE filename)
{
Montage *montage;
TypedData_Get_Struct(self, Montage, &rm_montage_data_type, montage);
strlcpy(montage->info->filename, StringValueCStr(filename), sizeof(montage->info->filename));
return filename;
}
|
#fill=(color) ⇒ Object
201 202 203 204 205 206 207 208 209 |
# File 'ext/RMagick/rmmontage.cpp', line 201
VALUE
Montage_fill_eq(VALUE self, VALUE color)
{
Montage *montage;
TypedData_Get_Struct(self, Montage, &rm_montage_data_type, montage);
Color_to_PixelColor(&montage->info->fill, color);
return color;
}
|
#font=(font) ⇒ Object
218 219 220 221 222 223 224 225 226 227 |
# File 'ext/RMagick/rmmontage.cpp', line 218
VALUE
Montage_font_eq(VALUE self, VALUE font)
{
Montage *montage;
TypedData_Get_Struct(self, Montage, &rm_montage_data_type, montage);
magick_clone_string(&montage->info->font, StringValueCStr(font));
return font;
}
|
#frame=(frame_arg) ⇒ Object
240 241 242 243 244 245 246 247 248 249 250 251 252 253 |
# File 'ext/RMagick/rmmontage.cpp', line 240
VALUE
Montage_frame_eq(VALUE self, VALUE frame_arg)
{
Montage *montage;
VALUE frame;
TypedData_Get_Struct(self, Montage, &rm_montage_data_type, montage);
frame = rb_String(frame_arg);
magick_clone_string(&montage->info->frame, StringValueCStr(frame));
RB_GC_GUARD(frame);
return frame_arg;
}
|
#freeze ⇒ Object
313 314 315 316 317 |
# File 'ext/RMagick/rmutil.cpp', line 313
VALUE
rm_no_freeze(VALUE obj)
{
rb_raise(rb_eTypeError, "can't freeze %s", rb_class2name(CLASS_OF(obj)));
}
|
#geometry=(geometry_arg) ⇒ Object
267 268 269 270 271 272 273 274 275 276 277 278 279 280 |
# File 'ext/RMagick/rmmontage.cpp', line 267
VALUE
Montage_geometry_eq(VALUE self, VALUE geometry_arg)
{
Montage *montage;
VALUE geometry;
TypedData_Get_Struct(self, Montage, &rm_montage_data_type, montage);
geometry = rb_String(geometry_arg);
magick_clone_string(&montage->info->geometry, StringValueCStr(geometry));
RB_GC_GUARD(geometry);
return geometry_arg;
}
|
#gravity=(gravity) ⇒ Object
289 290 291 292 293 294 295 296 297 |
# File 'ext/RMagick/rmmontage.cpp', line 289
VALUE
Montage_gravity_eq(VALUE self, VALUE gravity)
{
Montage *montage;
TypedData_Get_Struct(self, Montage, &rm_montage_data_type, montage);
VALUE_TO_ENUM(gravity, montage->info->gravity, GravityType);
return gravity;
}
|
#matte_color=(color) ⇒ Object
319 320 321 322 323 324 325 326 327 |
# File 'ext/RMagick/rmmontage.cpp', line 319
VALUE
Montage_matte_color_eq(VALUE self, VALUE color)
{
Montage *montage;
TypedData_Get_Struct(self, Montage, &rm_montage_data_type, montage);
Color_to_PixelColor(&montage->info->matte_color, color);
return color;
}
|
#pointsize=(size) ⇒ Object
336 337 338 339 340 341 342 343 344 |
# File 'ext/RMagick/rmmontage.cpp', line 336
VALUE
Montage_pointsize_eq(VALUE self, VALUE size)
{
Montage *montage;
TypedData_Get_Struct(self, Montage, &rm_montage_data_type, montage);
montage->info->pointsize = NUM2DBL(size);
return size;
}
|
#shadow=(shadow) ⇒ Object
353 354 355 356 357 358 359 360 361 |
# File 'ext/RMagick/rmmontage.cpp', line 353
VALUE
Montage_shadow_eq(VALUE self, VALUE shadow)
{
Montage *montage;
TypedData_Get_Struct(self, Montage, &rm_montage_data_type, montage);
montage->info->shadow = (MagickBooleanType) RTEST(shadow);
return shadow;
}
|
#stroke=(color) ⇒ Object
370 371 372 373 374 375 376 377 378 |
# File 'ext/RMagick/rmmontage.cpp', line 370
VALUE
Montage_stroke_eq(VALUE self, VALUE color)
{
Montage *montage;
TypedData_Get_Struct(self, Montage, &rm_montage_data_type, montage);
Color_to_PixelColor(&montage->info->stroke, color);
return color;
}
|
#texture=(texture) ⇒ Object
388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 |
# File 'ext/RMagick/rmmontage.cpp', line 388
VALUE
Montage_texture_eq(VALUE self, VALUE texture)
{
Montage *montage;
Image *texture_image;
char temp_name[MaxTextExtent];
TypedData_Get_Struct(self, Montage, &rm_montage_data_type, montage);
// If we had a previously defined temp texture image,
// remove it now in preparation for this new one.
if (montage->info->texture)
{
rm_delete_temp_image(montage->info->texture);
magick_free(montage->info->texture);
montage->info->texture = NULL;
}
texture = rm_cur_image(texture);
texture_image = rm_check_destroyed(texture);
// Write a temp copy of the image & save its name.
rm_write_temp_image(texture_image, temp_name, sizeof(temp_name));
magick_clone_string(&montage->info->texture, temp_name);
return texture;
}
|
#tile=(tile_arg) ⇒ Object
428 429 430 431 432 433 434 435 436 437 438 439 440 441 |
# File 'ext/RMagick/rmmontage.cpp', line 428
VALUE
Montage_tile_eq(VALUE self, VALUE tile_arg)
{
Montage *montage;
VALUE tile;
TypedData_Get_Struct(self, Montage, &rm_montage_data_type, montage);
tile = rb_String(tile_arg);
magick_clone_string(&montage->info->tile, StringValueCStr(tile));
RB_GC_GUARD(tile);
return tile_arg;
}
|
#title=(title) ⇒ Object
450 451 452 453 454 455 456 457 458 |
# File 'ext/RMagick/rmmontage.cpp', line 450
VALUE
Montage_title_eq(VALUE self, VALUE title)
{
Montage *montage;
TypedData_Get_Struct(self, Montage, &rm_montage_data_type, montage);
magick_clone_string(&montage->info->title, StringValueCStr(title));
return title;
}
|