Module: Magick::RVG::UseConstructors
- Included in:
- ClipPath, Embellishable, Pattern
- Defined in:
- lib/rvg/embellishable.rb
Overview
Methods that reference ("use") other drawable objects within a container
Instance Method Summary collapse
-
#use(obj, x = 0, y = 0, width = nil, height = nil) ⇒ Object
Reference an object to be inserted into the container's content.
Instance Method Details
#use(obj, x = 0, y = 0, width = nil, height = nil) ⇒ Object
Reference an object to be inserted into the container's
content. [x,y] is the offset from the upper-left
corner. If the argument is an RVG or Image object and width and height
are specified, these values will override the width and height
attributes on the argument.
319 320 321 322 323 |
# File 'lib/rvg/embellishable.rb', line 319 def use(obj, x = 0, y = 0, width = nil, height = nil) use = Use.new(obj, x, y, width, height) @content << use use end |