Class: Magick::Draw

Inherits:
Object
  • Object
show all
Includes:
DrawAttribute
Defined in:
lib/rmagick_internal.rb,
ext/RMagick/rmmain.cpp

Constant Summary collapse

ALIGN_TYPE_NAMES =

These hashes are used to map Magick constant values to the strings used in the primitives.

{
  LeftAlign.to_i => 'left',
  RightAlign.to_i => 'right',
  CenterAlign.to_i => 'center'
}.freeze
ANCHOR_TYPE_NAMES =
{
  StartAnchor.to_i => 'start',
  MiddleAnchor.to_i => 'middle',
  EndAnchor.to_i => 'end'
}.freeze
DECORATION_TYPE_NAMES =
{
  NoDecoration.to_i => 'none',
  UnderlineDecoration.to_i => 'underline',
  OverlineDecoration.to_i => 'overline',
  LineThroughDecoration.to_i => 'line-through'
}.freeze
FONT_WEIGHT_NAMES =
{
  AnyWeight.to_i => 'all',
  NormalWeight.to_i => 'normal',
  BoldWeight.to_i => 'bold',
  BolderWeight.to_i => 'bolder',
  LighterWeight.to_i => 'lighter'
}.freeze
GRAVITY_NAMES =
{
  NorthWestGravity.to_i => 'northwest',
  NorthGravity.to_i => 'north',
  NorthEastGravity.to_i => 'northeast',
  WestGravity.to_i => 'west',
  CenterGravity.to_i => 'center',
  EastGravity.to_i => 'east',
  SouthWestGravity.to_i => 'southwest',
  SouthGravity.to_i => 'south',
  SouthEastGravity.to_i => 'southeast'
}.freeze
PAINT_METHOD_NAMES =
{
  PointMethod.to_i => 'point',
  ReplaceMethod.to_i => 'replace',
  FloodfillMethod.to_i => 'floodfill',
  FillToBorderMethod.to_i => 'filltoborder',
  ResetMethod.to_i => 'reset'
}.freeze
STRETCH_TYPE_NAMES =
{
  NormalStretch.to_i => 'normal',
  UltraCondensedStretch.to_i => 'ultra-condensed',
  ExtraCondensedStretch.to_i => 'extra-condensed',
  CondensedStretch.to_i => 'condensed',
  SemiCondensedStretch.to_i => 'semi-condensed',
  SemiExpandedStretch.to_i => 'semi-expanded',
  ExpandedStretch.to_i => 'expanded',
  ExtraExpandedStretch.to_i => 'extra-expanded',
  UltraExpandedStretch.to_i => 'ultra-expanded',
  AnyStretch.to_i => 'all'
}.freeze
STYLE_TYPE_NAMES =
{
  NormalStyle.to_i => 'normal',
  ItalicStyle.to_i => 'italic',
  ObliqueStyle.to_i => 'oblique',
  AnyStyle.to_i => 'all'
}.freeze

Instance Method Summary collapse

Methods included from DrawAttribute

#affine=, #align=, #decorate=, #density=, #encoding=, #fill=, #fill_pattern=, #font=, #font_family=, #font_stretch=, #font_style=, #font_weight=, #gravity=, #interline_spacing=, #interword_spacing=, #kerning=, #pointsize=, #rotation=, #stroke=, #stroke_pattern=, #stroke_width=, #text_antialias=, #tile=, #undercolor=

Constructor Details

#initializeMagick::Draw

Initialize Draw object.



1210
1211
1212
1213
1214
1215
1216
1217
1218
1219
1220
1221
1222
1223
1224
1225
1226
# File 'ext/RMagick/rmdraw.cpp', line 1210

VALUE
Draw_initialize(VALUE self)
{
    Draw *draw, *draw_options;
    VALUE options;

    TypedData_Get_Struct(self, Draw, &rm_draw_data_type, draw);

    options = new_DrawOptions();
    TypedData_Get_Struct(options, Draw, &rm_draw_data_type, draw_options);
    draw->info = draw_options->info;
    draw_options->info = NULL;

    RB_GC_GUARD(options);

    return self;
}

Instance Method Details

#affine(sx, rx, ry, sy, tx, ty) ⇒ Object

Apply coordinate transformations to support scaling (s), rotation (r), and translation (t). Angles are specified in radians.



251
252
253
# File 'lib/rmagick_internal.rb', line 251

def affine(sx, rx, ry, sy, tx, ty)
  primitive 'affine ' + sprintf('%g,%g,%g,%g,%g,%g', sx, rx, ry, sy, tx, ty)
end

#alpha(x, y, method) ⇒ Object

Set alpha (make transparent) in image according to the specified colorization rule



257
258
259
260
261
# File 'lib/rmagick_internal.rb', line 257

def alpha(x, y, method)
  Kernel.raise ArgumentError, 'Unknown paint method' unless PAINT_METHOD_NAMES.key?(method.to_i)
  name = Gem::Version.new(Magick::IMAGEMAGICK_VERSION) > Gem::Version.new('7.0.0') ? 'alpha ' : 'matte '
  primitive name + sprintf('%g,%g, %s', x, y, PAINT_METHOD_NAMES[method.to_i])
end

#annotate(image_arg, width_arg, height_arg, x_arg, y_arg, text) ⇒ Magick::Draw

Annotates an image with text.

  • Additional Draw attribute methods may be called in the optional block, which is executed in the context of a Draw object.

Parameters:

  • image_arg (Magick::Image, Magick::ImageList)

    Either an imagelist or an image. If an imagelist, uses the current image.

  • width_arg (Numeric)

    the width

  • height_arg (Numeric)

    the height

  • x_arg (Numeric)

    x position

  • y_arg (Numeric)

    y position

  • text (String)

    the annotation text

Returns:



852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
872
873
874
875
876
877
878
879
880
881
882
883
884
885
886
887
888
889
890
891
892
893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
933
934
935
936
# File 'ext/RMagick/rmdraw.cpp', line 852

VALUE Draw_annotate(
                   VALUE self,
                   VALUE image_arg,
                   VALUE width_arg,
                   VALUE height_arg,
                   VALUE x_arg,
                   VALUE y_arg,
                   VALUE text)
{
    Draw *draw;
    Image *image;
    unsigned long width, height;
    long x, y;
    AffineMatrix keep;
    char geometry_str[100];
    char *embed_text;
#if defined(IMAGEMAGICK_7)
    ExceptionInfo *exception;
#endif

    // Save the affine matrix in case it is modified by
    // Draw#rotation=
    draw = get_draw(self);
    keep = draw->info->affine;

    image_arg = rm_cur_image(image_arg);
    image = rm_check_frozen(image_arg);

    // If we have an optional parm block, run it in self's context,
    // allowing the app a chance to modify the object's attributes
    if (rb_block_given_p())
    {
        rb_yield(self);
    }

    // Store in Draw structure. The text is drawn as given: it is not run
    // through InterpretImageProperties(), so a `%[...]` or `%x` escape in it is
    // not expanded. Everything those escapes provide is available directly from
    // Ruby -- Image#columns, Image#filename, Image#artifact and so on.
    embed_text = StringValueCStr(text);
    draw->info->text = ConstantString(embed_text);
#if defined(IMAGEMAGICK_7)
    exception = AcquireExceptionInfo();
#endif

    // Create geometry string, copy to Draw structure, overriding
    // any previously existing value.
    width  = NUM2ULONG(width_arg);
    height = NUM2ULONG(height_arg);
    x      = NUM2LONG(x_arg);
    y      = NUM2LONG(y_arg);

    if (width == 0 && height == 0)
    {
        snprintf(geometry_str, sizeof(geometry_str), "%+ld%+ld", x, y);
    }

    // WxH is non-zero
    else
    {
        snprintf(geometry_str, sizeof(geometry_str), "%lux%lu%+ld%+ld", width, height, x, y);
    }

    magick_clone_string(&draw->info->geometry, geometry_str);

#if defined(IMAGEMAGICK_7)
    GVL_STRUCT_TYPE(AnnotateImage) args = { image, draw->info, exception };
#else
    GVL_STRUCT_TYPE(AnnotateImage) args = { image, draw->info };
#endif
    CALL_FUNC_WITHOUT_GVL(GVL_FUNC(AnnotateImage), &args);

    magick_free(draw->info->text);
    draw->info->text = NULL;
    draw->info->affine = keep;

#if defined(IMAGEMAGICK_7)
    CHECK_EXCEPTION();
    DestroyExceptionInfo(exception);
#else
    rm_check_image_exception(image, RetainOnError);
#endif

    return self;
}

#arc(start_x, start_y, end_x, end_y, start_degrees, end_degrees) ⇒ Object

Draw an arc.



264
265
266
267
268
269
# File 'lib/rmagick_internal.rb', line 264

def arc(start_x, start_y, end_x, end_y, start_degrees, end_degrees)
  primitive 'arc ' + sprintf(
    '%g,%g %g,%g %g,%g',
    start_x, start_y, end_x, end_y, start_degrees, end_degrees
  )
end

#bezier(*points) ⇒ Object

Draw a bezier curve.



272
273
274
275
276
277
278
279
# File 'lib/rmagick_internal.rb', line 272

def bezier(*points)
  if points.empty?
    Kernel.raise ArgumentError, 'no points specified'
  elsif points.length.odd?
    Kernel.raise ArgumentError, 'odd number of arguments specified'
  end
  primitive 'bezier ' + points.map! { |x| sprintf('%g', x) }.join(',')
end

#circle(origin_x, origin_y, perim_x, perim_y) ⇒ Object

Draw a circle



282
283
284
# File 'lib/rmagick_internal.rb', line 282

def circle(origin_x, origin_y, perim_x, perim_y)
  primitive 'circle ' + sprintf('%g,%g %g,%g', origin_x, origin_y, perim_x, perim_y)
end

#clip_path(name) ⇒ Object

Invoke a clip-path defined by def_clip_path.



287
288
289
# File 'lib/rmagick_internal.rb', line 287

def clip_path(name)
  primitive "clip-path #{enquote(name)}"
end

#clip_rule(rule) ⇒ Object

Define the clipping rule.



292
293
294
295
296
# File 'lib/rmagick_internal.rb', line 292

def clip_rule(rule)
  rule = to_string(rule)
  Kernel.raise ArgumentError, "Unknown clipping rule #{rule}" unless %w[evenodd nonzero].include?(rule.downcase)
  primitive "clip-rule #{rule}"
end

#clip_units(unit) ⇒ Object

Define the clip units



299
300
301
302
303
# File 'lib/rmagick_internal.rb', line 299

def clip_units(unit)
  unit = to_string(unit)
  Kernel.raise ArgumentError, "Unknown clip unit #{unit}" unless %w[userspace userspaceonuse objectboundingbox].include?(unit.downcase)
  primitive "clip-units #{unit}"
end

#cloneMagick::Draw

Clones this object.

Returns:



944
945
946
947
948
949
950
951
952
953
954
955
956
957
958
# File 'ext/RMagick/rmdraw.cpp', line 944

VALUE
Draw_clone(VALUE self)
{
    VALUE clone;

    clone = Draw_dup(self);
    if (OBJ_FROZEN(self))
    {
        OBJ_FREEZE(clone);
    }

    RB_GC_GUARD(clone);

    return clone;
}

#color(x, y, method) ⇒ Object

Set color in image according to specified colorization rule. Rule is one of point, replace, floodfill, filltoborder,reset



307
308
309
310
# File 'lib/rmagick_internal.rb', line 307

def color(x, y, method)
  Kernel.raise ArgumentError, "Unknown PaintMethod: #{method}" unless PAINT_METHOD_NAMES.key?(method.to_i)
  primitive 'color ' + sprintf('%g,%g,%s', x, y, PAINT_METHOD_NAMES[method.to_i])
end

#composite(x, y, width, height, image) ⇒ Magick::Draw #composite(x, y, width, height, image, composite_op = Magick::OverCompositeOp) ⇒ Magick::Draw

Draw the image.

Overloads:

  • #composite(x, y, width, height, image) ⇒ Magick::Draw

    Parameters:

    • x (Numeric)

      x position

    • y (Numeric)

      y position

    • width (Numeric)

      the width

    • height (Numeric)

      the height

    • image (Magick::Image, Magick::ImageList)

      Either an imagelist or an image. If an imagelist, uses the current image.

  • #composite(x, y, width, height, image, composite_op = Magick::OverCompositeOp) ⇒ Magick::Draw
    • The "image" argument can be either an ImageList object or an Image argument.

    Parameters:

    • x (Numeric)

      x position

    • y (Numeric)

      y position

    • width (Numeric)

      the width

    • height (Numeric)

      the height

    • image (Magick::Image, Magick::ImageList)

      Either an imagelist or an image. If an imagelist, uses the current image.

    • composite_op (Magick::CompositeOperator) (defaults to: Magick::OverCompositeOp)

      the operator

Returns:



985
986
987
988
989
990
991
992
993
994
995
996
997
998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
# File 'ext/RMagick/rmdraw.cpp', line 985

VALUE
Draw_composite(int argc, VALUE *argv, VALUE self)
{
    Draw *draw;
    const char *op;
    double x, y, width, height;
    CompositeOperator composite_op;
    VALUE image;
    Image *comp_img;
    struct TmpFile_Name *tmpfile_name;
    char name[MaxTextExtent];
    // Buffer for "image" primitive
    char primitive[MaxTextExtent];

    if (argc < 5 || argc > 6)
    {
        rb_raise(rb_eArgError, "wrong number of arguments (%d for 5 or 6)", argc);
    }

    // Retrieve the image to composite
    image = rm_cur_image(argv[4]);
    comp_img = rm_check_destroyed(image);

    x = NUM2DBL(argv[0]);
    y = NUM2DBL(argv[1]);
    width  = NUM2DBL(argv[2]);
    height = NUM2DBL(argv[3]);

    composite_op = OverCompositeOp;
    if (argc == 6)
    {
        VALUE_TO_ENUM(argv[5], composite_op, CompositeOperator);
    }

    op = CommandOptionToMnemonic(MagickComposeOptions, composite_op);
    if (rm_strcasecmp("Unrecognized", op) == 0)
    {
        rb_raise(rb_eArgError, "unknown composite operator (%d)", composite_op);
    }

    TypedData_Get_Struct(self, Draw, &rm_draw_data_type, draw);

    // Create a temp copy of the composite image
    rm_write_temp_image(comp_img, name, sizeof(name));

    // Add the temp filename to the filename array.
    // Use Magick storage since we need to keep the list around
    // until destroy_Draw is called.
    tmpfile_name = (struct TmpFile_Name *)magick_malloc(sizeof(struct TmpFile_Name) + rm_strnlen_s(name, sizeof(name)));
    strcpy(tmpfile_name->name, name);
    tmpfile_name->next = draw->tmpfile_ary;
    draw->tmpfile_ary = tmpfile_name;

    // Form the drawing primitive
    snprintf(primitive, sizeof(primitive), "image %s %g,%g,%g,%g '%s'", op, x, y, width, height, name);


    // Send "primitive" to self.
    rb_funcall(self, rb_intern("primitive"), 1, rb_str_new2(primitive));

    RB_GC_GUARD(image);

    return self;
}

#decorate(decoration) ⇒ Object

Specify EITHER the text decoration (none, underline, overline, line-through) OR the text solid background color (any color name or spec)



314
315
316
317
318
319
320
# File 'lib/rmagick_internal.rb', line 314

def decorate(decoration)
  if DECORATION_TYPE_NAMES.key?(decoration.to_i)
    primitive "decorate #{DECORATION_TYPE_NAMES[decoration.to_i]}"
  else
    primitive "decorate #{enquote(decoration)}"
  end
end

#define_clip_path(name) ⇒ Object

Define a clip-path. A clip-path is a sequence of primitives bracketed by the "push clip-path " and "pop clip-path" primitives. Upon advice from the IM guys, we also bracket the clip-path primitives with "push(pop) defs" and "push (pop) graphic-context".



327
328
329
330
331
332
333
334
335
336
# File 'lib/rmagick_internal.rb', line 327

def define_clip_path(name)
  push('defs')
  push("clip-path #{enquote(name)}")
  push('graphic-context')
  yield
ensure
  pop('graphic-context')
  pop('clip-path')
  pop('defs')
end

#draw(image_arg) ⇒ Magick::Draw

Execute the stored drawing primitives on the current image.

Parameters:

Returns:



1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
1097
1098
# File 'ext/RMagick/rmdraw.cpp', line 1058

VALUE
Draw_draw(VALUE self, VALUE image_arg)
{
    Draw *draw;
    Image *image;
#if defined(IMAGEMAGICK_7)
    ExceptionInfo *exception;
#endif

    image_arg = rm_cur_image(image_arg);
    image = rm_check_frozen(image_arg);

    draw = get_draw(self);
    if (draw->primitives == 0)
    {
        rb_raise(rb_eArgError, "nothing to draw");
    }

    // Point the DrawInfo structure at the current set of primitives.
    magick_clone_string(&(draw->info->primitive), StringValueCStr(draw->primitives));

#if defined(IMAGEMAGICK_7)
    exception = AcquireExceptionInfo();
    GVL_STRUCT_TYPE(DrawImage) args = { image, draw->info, exception };
#else
    GVL_STRUCT_TYPE(DrawImage) args = { image, draw->info };
#endif
    CALL_FUNC_WITHOUT_GVL(GVL_FUNC(DrawImage), &args);

    magick_free(draw->info->primitive);
    draw->info->primitive = NULL;

#if defined(IMAGEMAGICK_7)
    CHECK_EXCEPTION();
    DestroyExceptionInfo(exception);
#else
    rm_check_image_exception(image, RetainOnError);
#endif

    return self;
}

#dupMagick::Draw

Duplicate a Draw object.

  • Constructs a new Draw object, then calls initialize_copy.

Returns:



1108
1109
1110
1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
# File 'ext/RMagick/rmdraw.cpp', line 1108

VALUE
Draw_dup(VALUE self)
{
    Draw *draw;
    VALUE dup;

    draw = ALLOC(Draw);
    memset(draw, 0, sizeof(Draw));
    dup = TypedData_Wrap_Struct(CLASS_OF(self), &rm_draw_data_type, draw);
    RB_GC_GUARD(dup);

    return rb_funcall(dup, rm_ID_initialize_copy, 1, self);
}

#ellipse(origin_x, origin_y, width, height, arc_start, arc_end) ⇒ Object

Draw an ellipse



339
340
341
342
343
344
# File 'lib/rmagick_internal.rb', line 339

def ellipse(origin_x, origin_y, width, height, arc_start, arc_end)
  primitive 'ellipse ' + sprintf(
    '%g,%g %g,%g %g,%g',
    origin_x, origin_y, width, height, arc_start, arc_end
  )
end

#encoding(encoding) ⇒ Object

Let anything through, but the only defined argument is "UTF-8". All others are apparently ignored.



348
349
350
# File 'lib/rmagick_internal.rb', line 348

def encoding(encoding)
  primitive "encoding #{enquote(encoding)}"
end

#fill(colorspec) ⇒ Object Also known as: fill_color, fill_pattern

Specify object fill, a color name or pattern name



353
354
355
# File 'lib/rmagick_internal.rb', line 353

def fill(colorspec)
  primitive "fill #{enquote(colorspec)}"
end

#fill_opacity(opacity) ⇒ Object

Specify fill opacity (use "xx%" to indicate percentage)



360
361
362
363
# File 'lib/rmagick_internal.rb', line 360

def fill_opacity(opacity)
  opacity = to_opacity(opacity)
  primitive "fill-opacity #{opacity}"
end

#fill_rule(rule) ⇒ Object



365
366
367
368
369
# File 'lib/rmagick_internal.rb', line 365

def fill_rule(rule)
  rule = to_string(rule)
  Kernel.raise ArgumentError, "Unknown fill rule #{rule}" unless %w[evenodd nonzero].include?(rule.downcase)
  primitive "fill-rule #{rule}"
end

#font(name) ⇒ Object

Specify text drawing font



372
373
374
# File 'lib/rmagick_internal.rb', line 372

def font(name)
  primitive "font #{enquote(name)}"
end

#font_family(name) ⇒ Object



376
377
378
# File 'lib/rmagick_internal.rb', line 376

def font_family(name)
  primitive "font-family #{enquote(name)}"
end

#font_stretch(stretch) ⇒ Object



380
381
382
383
# File 'lib/rmagick_internal.rb', line 380

def font_stretch(stretch)
  Kernel.raise ArgumentError, 'Unknown stretch type' unless STRETCH_TYPE_NAMES.key?(stretch.to_i)
  primitive "font-stretch #{STRETCH_TYPE_NAMES[stretch.to_i]}"
end

#font_style(style) ⇒ Object



385
386
387
388
# File 'lib/rmagick_internal.rb', line 385

def font_style(style)
  Kernel.raise ArgumentError, 'Unknown style type' unless STYLE_TYPE_NAMES.key?(style.to_i)
  primitive "font-style #{STYLE_TYPE_NAMES[style.to_i]}"
end

#font_weight(weight) ⇒ Object

The font weight argument can be either a font weight constant or [100,200,...,900]



392
393
394
395
396
397
398
# File 'lib/rmagick_internal.rb', line 392

def font_weight(weight)
  if weight.is_a?(WeightType)
    primitive "font-weight #{FONT_WEIGHT_NAMES[weight.to_i]}"
  else
    primitive "font-weight #{Integer(weight)}"
  end
end

#get_multiline_type_metrics(text) ⇒ Magick::TypeMetric #DrawMagick::TypeMetric

Returns measurements for a given font and text string.

  • If the image argument has been omitted, use a dummy image, but make sure the text has none of the special characters that refer to image attributes.

Overloads:

  • #get_multiline_type_metrics(text) ⇒ Magick::TypeMetric

    Parameters:

    • text (String)

      The string to be rendered.

  • #DrawMagick::TypeMetric

    Parameters:

    • image (Magick::Image, Magick::ImageList)

      Either an imagelist or an image. If an imagelist, uses the current image.

    • text (String)

      The string to be rendered.

Returns:

  • (Magick::TypeMetric)

    The information for a specific string if rendered on an image.



1167
1168
1169
1170
1171
1172
1173
1174
# File 'ext/RMagick/rmdraw.cpp', line 1167

VALUE
Draw_get_multiline_type_metrics(
                               int argc,
                               VALUE *argv,
                               VALUE self)
{
    return get_type_metrics(argc, argv, self, GVL_FUNC(GetMultilineTypeMetrics));
}

#get_type_metrics(text) ⇒ Magick::TypeMetric #get_type_metrics(image, text) ⇒ Magick::TypeMetric

Returns measurements for a given font and text string.

  • If the image argument has been omitted, use a dummy image, but make sure the text has none of the special characters that refer to image attributes.

Overloads:

  • #get_type_metrics(text) ⇒ Magick::TypeMetric

    Parameters:

    • text (String)

      The string to be rendered.

  • #get_type_metrics(image, text) ⇒ Magick::TypeMetric

    Parameters:

    • image (Magick::Image, Magick::ImageList)

      Either an imagelist or an image. If an imagelist, uses the current image.

    • text (String)

      The string to be rendered.

Returns:

  • (Magick::TypeMetric)

    The information for a specific string if rendered on an image.



1140
1141
1142
1143
1144
1145
1146
1147
# File 'ext/RMagick/rmdraw.cpp', line 1140

VALUE
Draw_get_type_metrics(
                     int argc,
                     VALUE *argv,
                     VALUE self)
{
    return get_type_metrics(argc, argv, self, GVL_FUNC(GetTypeMetrics));
}

#gravity(grav) ⇒ Object

Specify the text positioning gravity, one of: NorthWest, North, NorthEast, West, Center, East, SouthWest, South, SouthEast



402
403
404
405
# File 'lib/rmagick_internal.rb', line 402

def gravity(grav)
  Kernel.raise ArgumentError, 'Unknown text positioning gravity' unless GRAVITY_NAMES.key?(grav.to_i)
  primitive "gravity #{GRAVITY_NAMES[grav.to_i]}"
end

#image(composite, x, y, width, height, image_file_path) ⇒ Object



407
408
409
410
411
# File 'lib/rmagick_internal.rb', line 407

def image(composite, x, y, width, height, image_file_path)
  Kernel.raise ArgumentError, 'Unknown composite' unless composite.is_a?(CompositeOperator)
  composite_name = composite.to_s.sub!('CompositeOp', '')
  primitive 'image ' + sprintf('%s %g,%g %g,%g %s', composite_name, x, y, width, height, enquote(image_file_path))
end

#initialize_copy(orig) ⇒ Magick::Draw

Initialize clone, dup methods.

Parameters:

  • orig

    the original object

Returns:



1183
1184
1185
1186
1187
1188
1189
1190
1191
1192
1193
1194
1195
1196
1197
1198
1199
1200
1201
1202
# File 'ext/RMagick/rmdraw.cpp', line 1183

VALUE Draw_init_copy(VALUE self, VALUE orig)
{
    Draw *copy, *original;

    TypedData_Get_Struct(orig, Draw, &rm_draw_data_type, original);
    TypedData_Get_Struct(self, Draw, &rm_draw_data_type, copy);

    copy->info = CloneDrawInfo(NULL, original->info);
    if (!copy->info)
    {
        rb_raise(rb_eNoMemError, "not enough memory to continue");
    }

    if (original->primitives)
    {
        copy->primitives = rb_str_dup(original->primitives);
    }

    return self;
}

#inspectString

Display the primitives.

Returns:

  • (String)

    the draw primitives or the Ruby string "(no primitives defined)" if they are not defined



1235
1236
1237
1238
1239
1240
1241
1242
# File 'ext/RMagick/rmdraw.cpp', line 1235

VALUE
Draw_inspect(VALUE self)
{
    Draw *draw;

    TypedData_Get_Struct(self, Draw, &rm_draw_data_type, draw);
    return draw->primitives ? draw->primitives : rb_str_new2("(no primitives defined)");
}

#interline_spacing(space) ⇒ Object

IM 6.5.5-8 and later



414
415
416
# File 'lib/rmagick_internal.rb', line 414

def interline_spacing(space)
  primitive "interline-spacing #{Float(space)}"
end

#interword_spacing(space) ⇒ Object

IM 6.4.8-3 and later



419
420
421
# File 'lib/rmagick_internal.rb', line 419

def interword_spacing(space)
  primitive "interword-spacing #{Float(space)}"
end

#kerning(space) ⇒ Object

IM 6.4.8-3 and later



424
425
426
# File 'lib/rmagick_internal.rb', line 424

def kerning(space)
  primitive "kerning #{Float(space)}"
end

#line(start_x, start_y, end_x, end_y) ⇒ Object

Draw a line



429
430
431
# File 'lib/rmagick_internal.rb', line 429

def line(start_x, start_y, end_x, end_y)
  primitive 'line ' + sprintf('%g,%g %g,%g', start_x, start_y, end_x, end_y)
end

#marshal_dumpHash

TODO:

Handle gradients when christy gets the new gradient support added (23Dec08)

Dump custom marshal for Draw objects.

  • Instead of trying to replicate Ruby's support for cross-system marshalling, exploit it. Convert the Draw fields to Ruby objects and store them in a hash. Let Ruby marshal the hash.
  • Commented out code that dumps/loads fields that are used internally by ImageMagick and shouldn't be marshaled. I left the code as placeholders so I'll know which fields have been deliberately omitted.

Returns:

  • (Hash)

    the marshalled object



531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
# File 'ext/RMagick/rmdraw.cpp', line 531

VALUE
Draw_marshal_dump(VALUE self)
{
    Draw *draw;
    VALUE ddraw;

    draw = get_draw(self);

    // Raise an exception if the Draw has a non-NULL gradient or element_reference field
    if (draw->info->element_reference.type != UndefinedReference
        || draw->info->gradient.type != UndefinedGradient)
    {
        rb_raise(rb_eTypeError, "can't dump gradient definition");
    }

    ddraw = rb_hash_new();

    rb_hash_aset(ddraw, CSTR2SYM("affine"), Import_AffineMatrix(&draw->info->affine));
    rb_hash_aset(ddraw, CSTR2SYM("gravity"), INT2FIX(draw->info->gravity));
    rb_hash_aset(ddraw, CSTR2SYM("fill"), Pixel_from_PixelColor(&draw->info->fill));
    rb_hash_aset(ddraw, CSTR2SYM("stroke"), Pixel_from_PixelColor(&draw->info->stroke));
    rb_hash_aset(ddraw, CSTR2SYM("stroke_width"), rb_float_new(draw->info->stroke_width));
    rb_hash_aset(ddraw, CSTR2SYM("fill_pattern"), image_to_str(draw->info->fill_pattern));
    rb_hash_aset(ddraw, CSTR2SYM("stroke_pattern"), image_to_str(draw->info->stroke_pattern));
    rb_hash_aset(ddraw, CSTR2SYM("stroke_antialias"), draw->info->stroke_antialias ? Qtrue : Qfalse);
    rb_hash_aset(ddraw, CSTR2SYM("text_antialias"), draw->info->text_antialias ? Qtrue : Qfalse);
    rb_hash_aset(ddraw, CSTR2SYM("decorate"), INT2FIX(draw->info->decorate));
    rb_hash_aset(ddraw, CSTR2SYM("font"), MAGICK_STRING_TO_OBJ(draw->info->font));
    rb_hash_aset(ddraw, CSTR2SYM("family"), MAGICK_STRING_TO_OBJ(draw->info->family));
    rb_hash_aset(ddraw, CSTR2SYM("style"), INT2FIX(draw->info->style));
    rb_hash_aset(ddraw, CSTR2SYM("stretch"), INT2FIX(draw->info->stretch));
    rb_hash_aset(ddraw, CSTR2SYM("weight"), ULONG2NUM(draw->info->weight));
    rb_hash_aset(ddraw, CSTR2SYM("encoding"), MAGICK_STRING_TO_OBJ(draw->info->encoding));
    rb_hash_aset(ddraw, CSTR2SYM("pointsize"), rb_float_new(draw->info->pointsize));
    rb_hash_aset(ddraw, CSTR2SYM("density"), MAGICK_STRING_TO_OBJ(draw->info->density));
    rb_hash_aset(ddraw, CSTR2SYM("align"), INT2FIX(draw->info->align));
    rb_hash_aset(ddraw, CSTR2SYM("undercolor"), Pixel_from_PixelColor(&draw->info->undercolor));
    rb_hash_aset(ddraw, CSTR2SYM("clip_units"), INT2FIX(draw->info->clip_units));
#if defined(IMAGEMAGICK_7)
    rb_hash_aset(ddraw, CSTR2SYM("alpha"), QUANTUM2NUM(draw->info->alpha));
#else
    rb_hash_aset(ddraw, CSTR2SYM("opacity"), QUANTUM2NUM(draw->info->opacity));
#endif
    rb_hash_aset(ddraw, CSTR2SYM("kerning"), rb_float_new(draw->info->kerning));
    rb_hash_aset(ddraw, CSTR2SYM("interword_spacing"), rb_float_new(draw->info->interword_spacing));

    // Non-DrawInfo fields
    rb_hash_aset(ddraw, CSTR2SYM("primitives"), draw->primitives);

    return ddraw;
}

#marshal_load(ddraw) ⇒ Magick::Draw

Load the marshalled object

Parameters:

  • ddraw (Hash)

    the marshalled object

Returns:



590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
# File 'ext/RMagick/rmdraw.cpp', line 590

VALUE
Draw_marshal_load(VALUE self, VALUE ddraw)
{
    Draw *draw;
    VALUE val;

    TypedData_Get_Struct(self, Draw, &rm_draw_data_type, draw);

    Check_Type(ddraw, T_HASH);

    if (draw->info == NULL)
    {
        ImageInfo *image_info;

        image_info = CloneImageInfo(NULL);
        draw->info = CloneDrawInfo(image_info, (DrawInfo *) NULL);
        DestroyImageInfo(image_info);
    }
    OBJ_TO_MAGICK_STRING(draw->info->geometry, rb_hash_aref(ddraw, CSTR2SYM("geometry")));

    val = rb_hash_aref(ddraw, CSTR2SYM("affine"));
    Export_AffineMatrix(&draw->info->affine, val);

    draw->info->gravity = (GravityType) FIX2INT(rb_hash_aref(ddraw, CSTR2SYM("gravity")));

    val = rb_hash_aref(ddraw, CSTR2SYM("fill"));
    Color_to_PixelColor(&draw->info->fill, val);

    val = rb_hash_aref(ddraw, CSTR2SYM("stroke"));
    Color_to_PixelColor(&draw->info->stroke, val);

    draw->info->stroke_width = NUM2DBL(rb_hash_aref(ddraw, CSTR2SYM("stroke_width")));
    draw->info->fill_pattern = str_to_image(rb_hash_aref(ddraw, CSTR2SYM("fill_pattern")));
    draw->info->stroke_pattern = str_to_image(rb_hash_aref(ddraw, CSTR2SYM("stroke_pattern")));
    draw->info->stroke_antialias = (MagickBooleanType)RTEST(rb_hash_aref(ddraw, CSTR2SYM("stroke_antialias")));
    draw->info->text_antialias = (MagickBooleanType)RTEST(rb_hash_aref(ddraw, CSTR2SYM("text_antialias")));
    draw->info->decorate = (DecorationType) FIX2INT(rb_hash_aref(ddraw, CSTR2SYM("decorate")));
    OBJ_TO_MAGICK_STRING(draw->info->font, rb_hash_aref(ddraw, CSTR2SYM("font")));
    OBJ_TO_MAGICK_STRING(draw->info->family, rb_hash_aref(ddraw, CSTR2SYM("family")));

    draw->info->style = (StyleType) FIX2INT(rb_hash_aref(ddraw, CSTR2SYM("style")));
    draw->info->stretch = (StretchType) FIX2INT(rb_hash_aref(ddraw, CSTR2SYM("stretch")));
    draw->info->weight = NUM2ULONG(rb_hash_aref(ddraw, CSTR2SYM("weight")));
    OBJ_TO_MAGICK_STRING(draw->info->encoding, rb_hash_aref(ddraw, CSTR2SYM("encoding")));
    draw->info->pointsize = NUM2DBL(rb_hash_aref(ddraw, CSTR2SYM("pointsize")));
    OBJ_TO_MAGICK_STRING(draw->info->density, rb_hash_aref(ddraw, CSTR2SYM("density")));
    draw->info->align = (AlignType) FIX2INT(rb_hash_aref(ddraw, CSTR2SYM("align")));

    val = rb_hash_aref(ddraw, CSTR2SYM("undercolor"));
    Color_to_PixelColor(&draw->info->undercolor, val);

    draw->info->clip_units = (ClipPathUnits)FIX2INT(rb_hash_aref(ddraw, CSTR2SYM("clip_units")));
#if defined(IMAGEMAGICK_7)
    draw->info->alpha = NUM2QUANTUM(rb_hash_aref(ddraw, CSTR2SYM("alpha")));
#else
    draw->info->opacity = NUM2QUANTUM(rb_hash_aref(ddraw, CSTR2SYM("opacity")));
#endif
    draw->info->kerning = NUM2DBL(rb_hash_aref(ddraw, CSTR2SYM("kerning")));
    draw->info->interword_spacing = NUM2DBL(rb_hash_aref(ddraw, CSTR2SYM("interword_spacing")));

    draw->primitives = rb_hash_aref(ddraw, CSTR2SYM("primitives"));

    RB_GC_GUARD(val);

    return self;
}

#opacity(opacity) ⇒ Object

Specify drawing fill and stroke opacities. If the value is a string ending with a %, the number will be multiplied by 0.01.



435
436
437
438
# File 'lib/rmagick_internal.rb', line 435

def opacity(opacity)
  opacity = to_opacity(opacity)
  primitive "opacity #{opacity}"
end

#path(cmds) ⇒ Object

Draw using SVG-compatible path drawing commands. Note that the primitive requires that the commands be surrounded by quotes or apostrophes. Here we simply use apostrophes.



443
444
445
# File 'lib/rmagick_internal.rb', line 443

def path(cmds)
  primitive "path #{enquote(cmds)}"
end

#pattern(name, x, y, width, height) ⇒ Object

Define a pattern. In the block, call primitive methods to draw the pattern. Reference the pattern by using its name as the argument to the 'fill' or 'stroke' methods



450
451
452
453
454
455
456
457
458
459
# File 'lib/rmagick_internal.rb', line 450

def pattern(name, x, y, width, height)
  push('defs')
  push("pattern #{to_string(name)} " + sprintf('%g %g %g %g', x, y, width, height))
  push('graphic-context')
  yield
ensure
  pop('graphic-context')
  pop('pattern')
  pop('defs')
end

#point(x, y) ⇒ Object

Set point to fill color.



462
463
464
# File 'lib/rmagick_internal.rb', line 462

def point(x, y)
  primitive 'point ' + sprintf('%g,%g', x, y)
end

#pointsize(points) ⇒ Object Also known as: font_size

Specify the font size in points. Yes, the primitive is "font-size" but in other places this value is called the "pointsize". Give it both names.



468
469
470
# File 'lib/rmagick_internal.rb', line 468

def pointsize(points)
  primitive 'font-size ' + sprintf('%g', points)
end

#polygon(*points) ⇒ Object

Draw a polygon



474
475
476
477
478
479
480
481
# File 'lib/rmagick_internal.rb', line 474

def polygon(*points)
  if points.empty?
    Kernel.raise ArgumentError, 'no points specified'
  elsif points.length.odd?
    Kernel.raise ArgumentError, 'odd number of points specified'
  end
  primitive 'polygon ' + points.map! { |x| sprintf('%g', x) }.join(',')
end

#polyline(*points) ⇒ Object

Draw a polyline



484
485
486
487
488
489
490
491
# File 'lib/rmagick_internal.rb', line 484

def polyline(*points)
  if points.empty?
    Kernel.raise ArgumentError, 'no points specified'
  elsif points.length.odd?
    Kernel.raise ArgumentError, 'odd number of points specified'
  end
  primitive 'polyline ' + points.map! { |x| sprintf('%g', x) }.join(',')
end

#pop(*what) ⇒ Object

Return to the previously-saved set of whatever pop('graphic-context') (the default if no arguments) pop('defs') pop('gradient') pop('pattern')



499
500
501
502
503
504
505
# File 'lib/rmagick_internal.rb', line 499

def pop(*what)
  if what.empty?
    primitive 'pop graphic-context'
  else
    primitive 'pop ' + what.map { |x| to_string(x) }.join(' ')
  end
end

#primitive(primitive) ⇒ Magick::Draw

Add a drawing primitive to the list of primitives in the Draw object.

Parameters:

  • primitive (String)

    the primitive to add

Returns:



1271
1272
1273
1274
1275
1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
# File 'ext/RMagick/rmdraw.cpp', line 1271

VALUE
Draw_primitive(VALUE self, VALUE primitive)
{
    Draw *draw;

    rb_check_frozen(self);
    StringValue(primitive);
    TypedData_Get_Struct(self, Draw, &rm_draw_data_type, draw);

    if (draw->primitives == (VALUE)0)
    {
        draw->primitives = rb_str_dup(primitive);
    }
    else
    {
        draw->primitives = rb_str_concat(draw->primitives, rb_str_new2("\n"));
        draw->primitives = rb_str_concat(draw->primitives, primitive);
    }

    return self;
}

#push(*what) ⇒ Object

Push the current set of drawing options. Also you can use push('graphic-context') (the default if no arguments) push('defs') push('gradient') push('pattern')



512
513
514
515
516
517
518
# File 'lib/rmagick_internal.rb', line 512

def push(*what)
  if what.empty?
    primitive 'push graphic-context'
  else
    primitive 'push ' + what.map { |x| to_string(x) }.join(' ')
  end
end

#rectangle(upper_left_x, upper_left_y, lower_right_x, lower_right_y) ⇒ Object

Draw a rectangle



521
522
523
524
525
526
# File 'lib/rmagick_internal.rb', line 521

def rectangle(upper_left_x, upper_left_y, lower_right_x, lower_right_y)
  primitive 'rectangle ' + sprintf(
    '%g,%g %g,%g',
    upper_left_x, upper_left_y, lower_right_x, lower_right_y
  )
end

#rotate(angle) ⇒ Object

Specify coordinate space rotation. "angle" is measured in degrees



529
530
531
# File 'lib/rmagick_internal.rb', line 529

def rotate(angle)
  primitive 'rotate ' + sprintf('%g', angle)
end

#roundrectangle(center_x, center_y, width, height, corner_width, corner_height) ⇒ Object

Draw a rectangle with rounded corners



534
535
536
537
538
539
# File 'lib/rmagick_internal.rb', line 534

def roundrectangle(center_x, center_y, width, height, corner_width, corner_height)
  primitive 'roundrectangle ' + sprintf(
    '%g,%g,%g,%g,%g,%g',
    center_x, center_y, width, height, corner_width, corner_height
  )
end

#scale(x, y) ⇒ Object

Specify scaling to be applied to coordinate space on subsequent drawing commands.



542
543
544
# File 'lib/rmagick_internal.rb', line 542

def scale(x, y)
  primitive 'scale ' + sprintf('%g,%g', x, y)
end

#skewx(angle) ⇒ Object



546
547
548
# File 'lib/rmagick_internal.rb', line 546

def skewx(angle)
  primitive 'skewX ' + sprintf('%g', angle)
end

#skewy(angle) ⇒ Object



550
551
552
# File 'lib/rmagick_internal.rb', line 550

def skewy(angle)
  primitive 'skewY ' + sprintf('%g', angle)
end

#stroke(colorspec) ⇒ Object Also known as: stroke_color, stroke_pattern

Specify the object stroke, a color name or pattern name.



555
556
557
# File 'lib/rmagick_internal.rb', line 555

def stroke(colorspec)
  primitive "stroke #{enquote(colorspec)}"
end

#stroke_antialias(bool) ⇒ Object

Specify if stroke should be antialiased or not



562
563
564
565
# File 'lib/rmagick_internal.rb', line 562

def stroke_antialias(bool)
  bool = bool ? '1' : '0'
  primitive "stroke-antialias #{bool}"
end

#stroke_dasharray(*list) ⇒ Object

Specify a stroke dash pattern



568
569
570
571
572
573
574
575
576
577
# File 'lib/rmagick_internal.rb', line 568

def stroke_dasharray(*list)
  if list.empty?
    primitive 'stroke-dasharray none'
  else
    list.map! { |x| Float(x) }.each do |x|
      Kernel.raise ArgumentError, "dash array elements must be > 0 (#{x} given)" if x <= 0
    end
    primitive "stroke-dasharray #{list.join(',')}"
  end
end

#stroke_dashoffset(value = 0) ⇒ Object

Specify the initial offset in the dash pattern



580
581
582
# File 'lib/rmagick_internal.rb', line 580

def stroke_dashoffset(value = 0)
  primitive 'stroke-dashoffset ' + sprintf('%g', value)
end

#stroke_linecap(value) ⇒ Object



584
585
586
587
588
# File 'lib/rmagick_internal.rb', line 584

def stroke_linecap(value)
  value = to_string(value)
  Kernel.raise ArgumentError, "Unknown linecap type: #{value}" unless %w[butt round square].include?(value.downcase)
  primitive "stroke-linecap #{value}"
end

#stroke_linejoin(value) ⇒ Object



590
591
592
593
594
# File 'lib/rmagick_internal.rb', line 590

def stroke_linejoin(value)
  value = to_string(value)
  Kernel.raise ArgumentError, "Unknown linejoin type: #{value}" unless %w[round miter bevel].include?(value.downcase)
  primitive "stroke-linejoin #{value}"
end

#stroke_miterlimit(value) ⇒ Object



596
597
598
599
600
# File 'lib/rmagick_internal.rb', line 596

def stroke_miterlimit(value)
  value = Float(value)
  Kernel.raise ArgumentError, 'miterlimit must be >= 1' if value < 1
  primitive "stroke-miterlimit #{value}"
end

#stroke_opacity(opacity) ⇒ Object

Specify opacity of stroke drawing color (use "xx%" to indicate percentage)



604
605
606
607
# File 'lib/rmagick_internal.rb', line 604

def stroke_opacity(opacity)
  opacity = to_opacity(opacity)
  primitive "stroke-opacity #{opacity}"
end

#stroke_width(pixels) ⇒ Object

Specify stroke (outline) width in pixels.



610
611
612
# File 'lib/rmagick_internal.rb', line 610

def stroke_width(pixels)
  primitive 'stroke-width ' + sprintf('%g', pixels)
end

#text(x, y, text) ⇒ Object

Draw text at position x,y. Add quotes to text that is not already quoted.



615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
# File 'lib/rmagick_internal.rb', line 615

def text(x, y, text)
  text = to_string(text)
  Kernel.raise ArgumentError, 'missing text argument' if text.empty?
  # escape existing backslashes, so that they cannot escape the delimiter
  # added below and let the rest of the string be parsed as MVG
  text = text.gsub('\\') { |b| '\\' + b }
  if text.length > 2 && /\A(?:"[^"\\]+"|'[^'\\]+'|\{[^}\\]+\})\z/.match(text)
  # text already quoted
  elsif !text['\'']
    text = '\'' + text + '\''
  elsif !text['"']
    text = '"' + text + '"'
  elsif !(text['{'] || text['}'])
    text = '{' + text + '}'
  else
    # escape existing braces, surround with braces
    text = '{' + text.gsub(/[}]/) { |b| '\\' + b } + '}'
  end
  primitive 'text ' + sprintf('%g,%g %s', x, y, text)
end

#text_align(alignment) ⇒ Object

Specify text alignment relative to a given point



637
638
639
640
# File 'lib/rmagick_internal.rb', line 637

def text_align(alignment)
  Kernel.raise ArgumentError, "Unknown alignment constant: #{alignment}" unless ALIGN_TYPE_NAMES.key?(alignment.to_i)
  primitive "text-align #{ALIGN_TYPE_NAMES[alignment.to_i]}"
end

#text_anchor(anchor) ⇒ Object

SVG-compatible version of text_align



643
644
645
646
# File 'lib/rmagick_internal.rb', line 643

def text_anchor(anchor)
  Kernel.raise ArgumentError, "Unknown anchor constant: #{anchor}" unless ANCHOR_TYPE_NAMES.key?(anchor.to_i)
  primitive "text-anchor #{ANCHOR_TYPE_NAMES[anchor.to_i]}"
end

#text_antialias(boolean) ⇒ Object

Specify if rendered text is to be antialiased.



649
650
651
652
# File 'lib/rmagick_internal.rb', line 649

def text_antialias(boolean)
  boolean = boolean ? '1' : '0'
  primitive "text-antialias #{boolean}"
end

#text_undercolor(color) ⇒ Object

Specify color underneath text



655
656
657
# File 'lib/rmagick_internal.rb', line 655

def text_undercolor(color)
  primitive "text-undercolor #{enquote(color)}"
end

#translate(x, y) ⇒ Object

Specify center of coordinate space to use for subsequent drawing commands.



661
662
663
# File 'lib/rmagick_internal.rb', line 661

def translate(x, y)
  primitive 'translate ' + sprintf('%g,%g', x, y)
end