Module: Magick::DrawAttribute
- Included in:
- Draw, Image::DrawOptions, Image::PolaroidOptions
- Defined in:
- ext/RMagick/rmmain.cpp
Instance Method Summary collapse
-
#affine=(matrix) ⇒ Magick::AffineMatrix
Set the affine matrix from an AffineMatrix.
-
#align=(align) ⇒ Magick::AlignType
Set the text alignment from an AlignType.
-
#decorate=(decorate) ⇒ Magick::DecorationType
Set text decorate from an DecorationType.
-
#density=(density) ⇒ String
Set density.
-
#encoding=(encoding) ⇒ String
Set text encoding.
-
#fill=(fill) ⇒ Magick::Pixel, String
Set fill color.
-
#fill_pattern=(pattern) ⇒ Magick::Image
Accept an image as a fill pattern.
-
#font=(font) ⇒ String
Set the font name.
-
#font_family=(family) ⇒ String
Set the font family name.
-
#font_stretch=(stretch) ⇒ Magick::StretchType
Set the stretch as spacing between text characters.
-
#font_style=(style) ⇒ Magick::StyleType
Set font style.
-
#font_weight=(weight) ⇒ Magick::WeightType, Numeric
Set font weight.
-
#gravity=(grav) ⇒ Magick::GravityType
Set gravity to draw text.
-
#interline_spacing=(spacing) ⇒ Float
Set spacing between two lines.
-
#interword_spacing=(spacing) ⇒ Float
Set spacing between two words.
-
#kerning=(kerning) ⇒ Float
Set kerning as spacing between two letters.
-
#pointsize=(pointsize) ⇒ Float
Set point size to draw text.
-
#rotation=(deg) ⇒ Float
Set rotation.
-
#stroke=(stroke) ⇒ Magick::Pixel, String
Set stroke.
-
#stroke_pattern=(pattern) ⇒ Magick::Image
Accept an image as a stroke pattern.
-
#stroke_width=(stroke_width) ⇒ Float
Set stroke width.
-
#text_antialias=(text_antialias) ⇒ Boolean
Set whether to enable text antialias.
-
#tile=(image) ⇒ Magick::Image
Accept an image as a fill pattern.
-
#undercolor=(undercolor) ⇒ Magick::Pixel, String
Set undercolor.
Instance Method Details
#affine=(matrix) ⇒ Magick::AffineMatrix
Set the affine matrix from an AffineMatrix.
83 84 85 86 87 88 89 90 91 92 |
# File 'ext/RMagick/rmdraw.cpp', line 83
VALUE
Draw_affine_eq(VALUE self, VALUE matrix)
{
Draw *draw;
rb_check_frozen(self);
draw = get_draw(self);
Export_AffineMatrix(&draw->info->affine, matrix);
return matrix;
}
|
#align=(align) ⇒ Magick::AlignType
Set the text alignment from an AlignType.
101 102 103 104 105 106 107 108 109 110 |
# File 'ext/RMagick/rmdraw.cpp', line 101
VALUE
Draw_align_eq(VALUE self, VALUE align)
{
Draw *draw;
rb_check_frozen(self);
draw = get_draw(self);
VALUE_TO_ENUM(align, draw->info->align, AlignType);
return align;
}
|
#decorate=(decorate) ⇒ Magick::DecorationType
Set text decorate from an Magick::DecorationType.
119 120 121 122 123 124 125 126 127 128 |
# File 'ext/RMagick/rmdraw.cpp', line 119
VALUE
Draw_decorate_eq(VALUE self, VALUE decorate)
{
Draw *draw;
rb_check_frozen(self);
draw = get_draw(self);
VALUE_TO_ENUM(decorate, draw->info->decorate, DecorationType);
return decorate;
}
|
#density=(density) ⇒ String
Set density.
137 138 139 140 141 142 143 144 145 146 147 |
# File 'ext/RMagick/rmdraw.cpp', line 137
VALUE
Draw_density_eq(VALUE self, VALUE density)
{
Draw *draw;
rb_check_frozen(self);
draw = get_draw(self);
magick_clone_string(&draw->info->density, StringValueCStr(density));
return density;
}
|
#encoding=(encoding) ⇒ String
Set text encoding.
156 157 158 159 160 161 162 163 164 165 166 |
# File 'ext/RMagick/rmdraw.cpp', line 156
VALUE
Draw_encoding_eq(VALUE self, VALUE encoding)
{
Draw *draw;
rb_check_frozen(self);
draw = get_draw(self);
magick_clone_string(&draw->info->encoding, StringValueCStr(encoding));
return encoding;
}
|
#fill=(fill) ⇒ Magick::Pixel, String
Set fill color.
175 176 177 178 179 180 181 182 183 184 |
# File 'ext/RMagick/rmdraw.cpp', line 175
VALUE
Draw_fill_eq(VALUE self, VALUE fill)
{
Draw *draw;
rb_check_frozen(self);
draw = get_draw(self);
Color_to_PixelColor(&draw->info->fill, fill);
return fill;
}
|
#fill_pattern=(pattern) ⇒ Magick::Image
Accept an image as a fill pattern.
196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 |
# File 'ext/RMagick/rmdraw.cpp', line 196
VALUE
Draw_fill_pattern_eq(VALUE self, VALUE pattern)
{
Draw *draw;
rb_check_frozen(self);
draw = get_draw(self);
if (draw->info->fill_pattern != NULL)
{
// Do not trace destruction
DestroyImage(draw->info->fill_pattern);
draw->info->fill_pattern = NULL;
}
if (!NIL_P(pattern))
{
Image *image;
pattern = rm_cur_image(pattern);
image = rm_check_destroyed(pattern);
// Do not trace creation
draw->info->fill_pattern = rm_clone_image(image);
}
return pattern;
}
|
#font=(font) ⇒ String
Set the font name.
231 232 233 234 235 236 237 238 239 240 241 |
# File 'ext/RMagick/rmdraw.cpp', line 231
VALUE
Draw_font_eq(VALUE self, VALUE font)
{
Draw *draw;
rb_check_frozen(self);
draw = get_draw(self);
magick_clone_string(&draw->info->font, StringValueCStr(font));
return font;
}
|
#font_family=(family) ⇒ String
Set the font family name.
250 251 252 253 254 255 256 257 258 259 260 |
# File 'ext/RMagick/rmdraw.cpp', line 250
VALUE
Draw_font_family_eq(VALUE self, VALUE family)
{
Draw *draw;
rb_check_frozen(self);
draw = get_draw(self);
magick_clone_string(&draw->info->family, StringValueCStr(family));
return family;
}
|
#font_stretch=(stretch) ⇒ Magick::StretchType
Set the stretch as spacing between text characters.
269 270 271 272 273 274 275 276 277 278 |
# File 'ext/RMagick/rmdraw.cpp', line 269
VALUE
Draw_font_stretch_eq(VALUE self, VALUE stretch)
{
Draw *draw;
rb_check_frozen(self);
draw = get_draw(self);
VALUE_TO_ENUM(stretch, draw->info->stretch, StretchType);
return stretch;
}
|
#font_style=(style) ⇒ Magick::StyleType
Set font style.
287 288 289 290 291 292 293 294 295 296 |
# File 'ext/RMagick/rmdraw.cpp', line 287
VALUE
Draw_font_style_eq(VALUE self, VALUE style)
{
Draw *draw;
rb_check_frozen(self);
draw = get_draw(self);
VALUE_TO_ENUM(style, draw->info->style, StyleType);
return style;
}
|
#font_weight=(weight) ⇒ Magick::WeightType, Numeric
The font weight can be one of the font weight constants or a number between 100 and 900
Set font weight.
306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 |
# File 'ext/RMagick/rmdraw.cpp', line 306
VALUE
Draw_font_weight_eq(VALUE self, VALUE weight)
{
Draw *draw;
size_t w;
rb_check_frozen(self);
draw = get_draw(self);
if (FIXNUM_P(weight))
{
w = FIX2INT(weight);
if (w < 100 || w > 900)
{
rb_raise(rb_eArgError, "invalid font weight (%" RMIuSIZE " given)", w);
}
draw->info->weight = w;
}
else
{
VALUE_TO_ENUM(weight, w, WeightType);
switch (w)
{
case AnyWeight:
draw->info->weight = 0;
break;
case NormalWeight:
draw->info->weight = 400;
break;
case BoldWeight:
draw->info->weight = 700;
break;
case BolderWeight:
if (draw->info->weight <= 800)
draw->info->weight += 100;
break;
case LighterWeight:
if (draw->info->weight >= 100)
draw->info->weight -= 100;
break;
default:
rb_raise(rb_eArgError, "unknown font weight");
break;
}
}
return weight;
}
|
#gravity=(grav) ⇒ Magick::GravityType
Set gravity to draw text. Gravity affects text placement in bounding area according to rules:
NorthWestGravity- text bottom-left corner placed at top-leftNorthGravity- text bottom-center placed at top-centerNorthEastGravity- text bottom-right corner placed at top-rightWestGravity- text left-center placed at left-centerCenterGravity- text center placed at centerEastGravity- text right-center placed at right-centerSouthWestGravity- text top-left placed at bottom-leftSouthGravity- text top-center placed at bottom-centerSouthEastGravity- text top-right placed at bottom-right
373 374 375 376 377 378 379 380 381 382 383 |
# File 'ext/RMagick/rmdraw.cpp', line 373
VALUE
Draw_gravity_eq(VALUE self, VALUE grav)
{
Draw *draw;
rb_check_frozen(self);
draw = get_draw(self);
VALUE_TO_ENUM(grav, draw->info->gravity, GravityType);
return grav;
}
|
#interline_spacing=(spacing) ⇒ Float
Set spacing between two lines.
410 411 412 413 414 415 416 417 418 419 |
# File 'ext/RMagick/rmdraw.cpp', line 410
VALUE
Draw_interline_spacing_eq(VALUE self, VALUE spacing)
{
Draw *draw;
rb_check_frozen(self);
draw = get_draw(self);
draw->info->interline_spacing = NUM2DBL(spacing);
return spacing;
}
|
#interword_spacing=(spacing) ⇒ Float
Set spacing between two words.
428 429 430 431 432 433 434 435 436 437 |
# File 'ext/RMagick/rmdraw.cpp', line 428
VALUE
Draw_interword_spacing_eq(VALUE self, VALUE spacing)
{
Draw *draw;
rb_check_frozen(self);
draw = get_draw(self);
draw->info->interword_spacing = NUM2DBL(spacing);
return spacing;
}
|
#kerning=(kerning) ⇒ Float
Set kerning as spacing between two letters.
392 393 394 395 396 397 398 399 400 401 |
# File 'ext/RMagick/rmdraw.cpp', line 392
VALUE
Draw_kerning_eq(VALUE self, VALUE kerning)
{
Draw *draw;
rb_check_frozen(self);
draw = get_draw(self);
draw->info->kerning = NUM2DBL(kerning);
return kerning;
}
|
#pointsize=(pointsize) ⇒ Float
Set point size to draw text.
662 663 664 665 666 667 668 669 670 671 |
# File 'ext/RMagick/rmdraw.cpp', line 662
VALUE
Draw_pointsize_eq(VALUE self, VALUE pointsize)
{
Draw *draw;
rb_check_frozen(self);
draw = get_draw(self);
draw->info->pointsize = NUM2DBL(pointsize);
return pointsize;
}
|
#rotation=(deg) ⇒ Float
Set rotation. The argument should be in degrees.
680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 |
# File 'ext/RMagick/rmdraw.cpp', line 680
VALUE
Draw_rotation_eq(VALUE self, VALUE deg)
{
Draw *draw;
double degrees;
AffineMatrix affine, current;
rb_check_frozen(self);
draw = get_draw(self);
degrees = NUM2DBL(deg);
if (fabs(degrees) > DBL_EPSILON)
{
current = draw->info->affine;
affine.sx = cos(DegreesToRadians(fmod(degrees, 360.0)));
affine.rx = sin(DegreesToRadians(fmod(degrees, 360.0)));
affine.tx = 0.0;
affine.ry = (-sin(DegreesToRadians(fmod(degrees, 360.0))));
affine.sy = cos(DegreesToRadians(fmod(degrees, 360.0)));
affine.ty = 0.0;
draw->info->affine.sx = current.sx*affine.sx+current.ry*affine.rx;
draw->info->affine.rx = current.rx*affine.sx+current.sy*affine.rx;
draw->info->affine.ry = current.sx*affine.ry+current.ry*affine.sy;
draw->info->affine.sy = current.rx*affine.ry+current.sy*affine.sy;
draw->info->affine.tx = current.sx*affine.tx+current.ry*affine.ty+current.tx;
}
return deg;
}
|
#stroke=(stroke) ⇒ Magick::Pixel, String
Set stroke.
718 719 720 721 722 723 724 725 726 727 |
# File 'ext/RMagick/rmdraw.cpp', line 718
VALUE
Draw_stroke_eq(VALUE self, VALUE stroke)
{
Draw *draw;
rb_check_frozen(self);
draw = get_draw(self);
Color_to_PixelColor(&draw->info->stroke, stroke);
return stroke;
}
|
#stroke_pattern=(pattern) ⇒ Magick::Image
Accept an image as a stroke pattern.
738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 |
# File 'ext/RMagick/rmdraw.cpp', line 738
VALUE
Draw_stroke_pattern_eq(VALUE self, VALUE pattern)
{
Draw *draw;
rb_check_frozen(self);
draw = get_draw(self);
if (draw->info->stroke_pattern != NULL)
{
// Do not trace destruction
DestroyImage(draw->info->stroke_pattern);
draw->info->stroke_pattern = NULL;
}
if (!NIL_P(pattern))
{
Image *image;
// DestroyDrawInfo destroys the clone
pattern = rm_cur_image(pattern);
image = rm_check_destroyed(pattern);
// Do not trace creation
draw->info->stroke_pattern = rm_clone_image(image);
}
return pattern;
}
|
#stroke_width=(stroke_width) ⇒ Float
Set stroke width.
774 775 776 777 778 779 780 781 782 783 |
# File 'ext/RMagick/rmdraw.cpp', line 774
VALUE
Draw_stroke_width_eq(VALUE self, VALUE stroke_width)
{
Draw *draw;
rb_check_frozen(self);
draw = get_draw(self);
draw->info->stroke_width = NUM2DBL(stroke_width);
return stroke_width;
}
|
#text_antialias=(text_antialias) ⇒ Boolean
Set whether to enable text antialias.
792 793 794 795 796 797 798 799 800 801 |
# File 'ext/RMagick/rmdraw.cpp', line 792
VALUE
Draw_text_antialias_eq(VALUE self, VALUE text_antialias)
{
Draw *draw;
rb_check_frozen(self);
draw = get_draw(self);
draw->info->text_antialias = (MagickBooleanType) RTEST(text_antialias);
return text_antialias;
}
|
#tile=(image) ⇒ Magick::Image
Accept an image as a fill pattern. This is alias of #fill_pattern=.
810 811 812 813 814 |
# File 'ext/RMagick/rmdraw.cpp', line 810
VALUE
Draw_tile_eq(VALUE self, VALUE image)
{
return Draw_fill_pattern_eq(self, image);
}
|
#undercolor=(undercolor) ⇒ Magick::Pixel, String
Set undercolor.
823 824 825 826 827 828 829 830 831 832 |
# File 'ext/RMagick/rmdraw.cpp', line 823
VALUE
Draw_undercolor_eq(VALUE self, VALUE undercolor)
{
Draw *draw;
rb_check_frozen(self);
draw = get_draw(self);
Color_to_PixelColor(&draw->info->undercolor, undercolor);
return undercolor;
}
|