Class: Magick::ImageList
- Inherits:
-
Object
- Object
- Magick::ImageList
- Includes:
- Comparable, Enumerable
- Defined in:
- lib/rmagick_internal.rb,
ext/RMagick/rmmain.cpp
Overview
class Magick::Image
Defined Under Namespace
Classes: Montage
Instance Attribute Summary collapse
-
#scene ⇒ Object
Returns the value of attribute scene.
Instance Method Summary collapse
- #*(other) ⇒ Object
- #<<(obj) ⇒ Object
-
#<=>(other) ⇒ Object
Compare ImageLists Compare each image in turn until the result of a comparison is not 0.
- #[](*args) ⇒ Object
- #[]=(*args) ⇒ Object
-
#__respond_to__? ⇒ Object
Ensure respond_to? answers correctly when we are delegating to Image.
-
#animate(*args) ⇒ Magick::ImageList
Repeatedly display the images in the images array to an XWindow screen.
-
#append(stack_arg) ⇒ Magick::Image
Append all the images.
-
#average ⇒ Magick::Image
Average all images together.
- #clear ⇒ Object
- #clone ⇒ Object
-
#coalesce ⇒ Magick::ImageList
Composites a set of images while respecting any page offsets and disposal methods.
-
#collect ⇒ Object
(also: #map, #__map__)
override Enumerable#collect.
- #collect! ⇒ Object (also: #map!, #__map__!)
-
#combine(*args) ⇒ Magick::Image
Combines the images using the specified colorspace.
- #compact ⇒ Object
- #compact! ⇒ Object
-
#composite_layers(*args) ⇒ Magick::ImageList
An image from source images is composited over an image from receiver's list until one list is finished.
- #concat(other) ⇒ Object
-
#copy ⇒ Object
Make a deep copy.
-
#cur_image ⇒ Object
Return the current image.
-
#deconstruct ⇒ Magick::ImageList
Compare each image with the next in a sequence and returns the maximum bounding region of any pixel differences it discovers.
-
#delay=(d) ⇒ Object
Set same delay for all images.
- #delete(obj) ⇒ Object
- #delete_at(ndx) ⇒ Object
- #delete_if ⇒ Object
- #destroy! ⇒ Object
- #destroyed? ⇒ Boolean
-
#display {|info| ... } ⇒ Magick::ImageList
(also: #__display__)
Display all the images to an X window screen.
- #dup ⇒ Object
- #eql?(other) ⇒ Boolean
- #fill(*args, &block) ⇒ Object
-
#find_all ⇒ Object
(also: #select)
Override Enumerable's find_all.
-
#flatten_images ⇒ Magick::ImageList
Merge all the images into a single image.
- #from_blob(*blobs, &block) ⇒ Object
-
#initialize(*filenames, &block) ⇒ ImageList
constructor
Initialize new instances.
- #insert(index, *args) ⇒ Object
-
#inspect ⇒ Object
Call inspect for all the images.
-
#iterations=(n) ⇒ Object
Set the number of iterations of an animated GIF.
- #last(*args) ⇒ Object
-
#marshal_dump ⇒ Object
Custom marshal/unmarshal for Ruby 1.8.
- #marshal_load(ary) ⇒ Object
-
#method_missing(meth_id, *args) ⇒ Object
The ImageList class supports the Magick::Image class methods by simply sending the method to the current image.
-
#montage ⇒ Magick::ImageList
Tile one or more thumbnails across an image canvas.
-
#morph(nimages) ⇒ Magick::ImageList
Requires a minimum of two images.
-
#mosaic ⇒ Magick::Image
Merge all the images into a single image.
-
#new_image(cols, rows, *fill) ⇒ Object
Create a new image and add it to the end.
-
#optimize_layers(method) ⇒ Magick::ImageList
Optimizes or compares the images in the list.
- #partition ⇒ Object
-
#ping(*files, &block) ⇒ Object
Ping files and concatenate the new images.
- #pop ⇒ Object
- #push(*objs) ⇒ Object
-
#quantize(number_colors = 256, colorspace = Magick::RGBColorspace, dither = true, tree_depth = 0, measure_error = false) ⇒ Magick::ImageList
Analyzes the colors within a set of reference images and chooses a fixed number of colors to represent the set.
-
#read(*files, &block) ⇒ Object
Read files and concatenate the new images.
-
#reject ⇒ Object
override Enumerable's reject.
- #reject! ⇒ Object
-
#remap(remap_image = nil, dither_method = Magick::RiemersmaDitherMethod) ⇒ Magick::ImageList
(also: #affinity)
Reduce the colors used in the image list to the set of colors in
remap_image. - #replace(other) ⇒ Object
- #respond_to?(meth_id, priv = false) ⇒ Boolean
- #reverse ⇒ Object
- #reverse! ⇒ Object
- #reverse_each ⇒ Object
- #shift ⇒ Object
- #slice(*args) ⇒ Object
- #slice!(*args) ⇒ Object
- #sort!(*args) ⇒ Object
- #ticks_per_second=(t) ⇒ Object
- #to_a ⇒ Object
-
#to_blob ⇒ String
Return the imagelist as a blob (a String).
- #uniq ⇒ Object
- #uniq!(*_args) ⇒ Object
- #unshift(obj) ⇒ Object
- #values_at(*args) ⇒ Object (also: #indexes, #indices)
-
#write(file) {|info| ... } ⇒ Object
Write all the images to the specified file.
Constructor Details
#initialize(*filenames, &block) ⇒ ImageList
Initialize new instances
1551 1552 1553 1554 1555 1556 1557 1558 1559 |
# File 'lib/rmagick_internal.rb', line 1551 def initialize(*filenames, &block) @images = [] @scene = nil filenames.each do |f| Magick::Image.read(f, &block).each { |n| @images << n } end @scene = length - 1 if length > 0 # last image in array end |
Dynamic Method Handling
This class handles dynamic methods through the method_missing method
#method_missing(meth_id, *args) ⇒ Object
The ImageList class supports the Magick::Image class methods by simply sending the method to the current image. If the method isn't explicitly supported, send it to the current image in the array. If there are no images, send it up the line. Catch a NameError and emit a useful message.
1612 1613 1614 1615 1616 1617 1618 1619 1620 1621 1622 1623 1624 1625 |
# File 'lib/rmagick_internal.rb', line 1612 def method_missing(meth_id, *args, &) if @scene img = @images[@scene] new_img = img.public_send(meth_id, *args, &) img.equal?(new_img) ? self : new_img else super end rescue NoMethodError Kernel.raise NoMethodError, "undefined method `#{meth_id.id2name}' for #{self.class}" rescue StandardError $ERROR_POSITION.delete_if { |s| /:in `send'$/.match(s) || /:in `method_missing'$/.match(s) } Kernel.raise end |
Instance Attribute Details
#scene ⇒ Object
Returns the value of attribute scene.
1239 1240 1241 |
# File 'lib/rmagick_internal.rb', line 1239 def scene @scene end |
Instance Method Details
#*(other) ⇒ Object
1316 1317 1318 1319 1320 1321 1322 1323 |
# File 'lib/rmagick_internal.rb', line 1316 def *(other) Kernel.raise ArgumentError, "Integer required (#{other.class} given)" unless other.is_a? Integer current = get_current ilist = self.class.new (@images * other).each { |image| ilist << image } ilist.set_current current ilist end |
#<<(obj) ⇒ Object
1325 1326 1327 1328 1329 1330 |
# File 'lib/rmagick_internal.rb', line 1325 def <<(obj) assert_image obj @images << obj @scene = @images.length - 1 self end |
#<=>(other) ⇒ Object
Compare ImageLists Compare each image in turn until the result of a comparison is not 0. If all comparisons return 0, then return if A.scene != B.scene return A.length <=> B.length
1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 |
# File 'lib/rmagick_internal.rb', line 1337 def <=>(other) return unless other.is_a? self.class size = [length, other.length].min size.times do |x| r = self[x] <=> other[x] return r unless r.zero? end return 0 if @scene.nil? && other.scene.nil? return if @scene.nil? && !other.scene.nil? return if !@scene.nil? && other.scene.nil? r = scene <=> other.scene return r unless r.zero? length <=> other.length end |
#[](*args) ⇒ Object
1356 1357 1358 1359 1360 1361 1362 1363 1364 |
# File 'lib/rmagick_internal.rb', line 1356 def [](*args) a = @images[*args] if a.respond_to?(:each) ilist = self.class.new a.each { |image| ilist << image } a = ilist end a end |
#[]=(*args) ⇒ Object
1366 1367 1368 1369 1370 1371 1372 1373 1374 1375 1376 1377 |
# File 'lib/rmagick_internal.rb', line 1366 def []=(*args) obj = @images.[]=(*args) if obj.respond_to?(:each) assert_image_array(obj) set_current obj.last.__id__ elsif obj assert_image(obj) set_current obj.__id__ else set_current nil end end |
#__respond_to__? ⇒ Object
Ensure respond_to? answers correctly when we are delegating to Image
1708 |
# File 'lib/rmagick_internal.rb', line 1708 alias __respond_to__? respond_to? |
#animate ⇒ Magick::ImageList #animate(delay) {|info| ... } ⇒ Magick::ImageList
Repeatedly display the images in the images array to an XWindow screen. The
delay argument is the number of 1/100ths of a second (0 to 65535) to delay
between images.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'ext/RMagick/rmilist.cpp', line 80
VALUE
ImageList_animate(int argc, VALUE *argv, VALUE self)
{
Image *images;
Info *info;
VALUE info_obj;
unsigned int delay;
#if defined(IMAGEMAGICK_7)
ExceptionInfo *exception;
#endif
if (argc == 1)
{
delay = NUM2UINT(argv[0]);
}
if (argc > 1)
{
rb_raise(rb_eArgError, "wrong number of arguments (%d for 0 or 1)", argc);
}
// Create a new Info object to use with this call
info_obj = rm_info_new();
// Convert the images array to an images sequence.
VALUE clones;
images = images_from_imagelist(self, &clones);
if (argc == 1)
{
Image *img;
for (img = images; img; img = GetNextImageInList(img))
{
img->delay = delay;
}
}
TypedData_Get_Struct(info_obj, Info, &rm_info_data_type, info);
#if defined(IMAGEMAGICK_7)
exception = AcquireExceptionInfo();
GVL_STRUCT_TYPE(AnimateImages) args = { info, images, exception };
CALL_FUNC_WITHOUT_GVL(GVL_FUNC(AnimateImages), &args);
rm_split(images);
CHECK_EXCEPTION();
DestroyExceptionInfo(exception);
#else
GVL_STRUCT_TYPE(AnimateImages) args = { info, images };
CALL_FUNC_WITHOUT_GVL(GVL_FUNC(AnimateImages), &args);
rm_split(images);
rm_check_image_exception(images, RetainOnError);
#endif
RB_GC_GUARD(clones);
RB_GC_GUARD(info_obj);
return self;
}
|
#append(stack_arg) ⇒ Magick::Image
Append all the images
145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'ext/RMagick/rmilist.cpp', line 145
VALUE
ImageList_append(VALUE self, VALUE stack_arg)
{
Image *images, *new_image;
MagickBooleanType stack;
ExceptionInfo *exception;
// Convert the image array to an image sequence.
VALUE clones;
images = images_from_imagelist(self, &clones);
// If stack == true, stack rectangular images top-to-bottom,
// otherwise left-to-right.
stack = (MagickBooleanType)RTEST(stack_arg);
exception = AcquireExceptionInfo();
GVL_STRUCT_TYPE(AppendImages) args = { images, stack, exception };
new_image = (Image *)CALL_FUNC_WITHOUT_GVL(GVL_FUNC(AppendImages), &args);
rm_split(images);
RB_GC_GUARD(clones);
rm_check_exception(exception, new_image, DestroyOnError);
DestroyExceptionInfo(exception);
return rm_image_new(new_image);
}
|
#average ⇒ Magick::Image
Average all images together
177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'ext/RMagick/rmilist.cpp', line 177
VALUE
ImageList_average(VALUE self)
{
Image *images, *new_image;
ExceptionInfo *exception;
// Convert the images array to an images sequence.
VALUE clones;
images = images_from_imagelist(self, &clones);
exception = AcquireExceptionInfo();
GVL_STRUCT_TYPE(EvaluateImages) args = { images, MeanEvaluateOperator, exception };
new_image = (Image *)CALL_FUNC_WITHOUT_GVL(GVL_FUNC(EvaluateImages), &args);
rm_split(images);
RB_GC_GUARD(clones);
rm_check_exception(exception, new_image, DestroyOnError);
DestroyExceptionInfo(exception);
return rm_image_new(new_image);
}
|
#clear ⇒ Object
1396 1397 1398 1399 |
# File 'lib/rmagick_internal.rb', line 1396 def clear @scene = nil @images.clear end |
#clone ⇒ Object
1401 1402 1403 1404 1405 |
# File 'lib/rmagick_internal.rb', line 1401 def clone ditto = dup ditto.freeze if frozen? ditto end |
#coalesce ⇒ Magick::ImageList
Composites a set of images while respecting any page offsets and disposal methods.
- Respects the delay, matte, and start_loop fields in each image.
207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 |
# File 'ext/RMagick/rmilist.cpp', line 207
VALUE
ImageList_coalesce(VALUE self)
{
Image *images, *new_images;
ExceptionInfo *exception;
// Convert the image array to an image sequence.
VALUE clones;
images = images_from_imagelist(self, &clones);
exception = AcquireExceptionInfo();
GVL_STRUCT_TYPE(CoalesceImages) args = { images, exception };
new_images = (Image *)CALL_FUNC_WITHOUT_GVL(GVL_FUNC(CoalesceImages), &args);
rm_split(images);
RB_GC_GUARD(clones);
rm_check_exception(exception, new_images, DestroyOnError);
DestroyExceptionInfo(exception);
return rm_imagelist_from_images(new_images);
}
|
#collect ⇒ Object Also known as: map, __map__
override Enumerable#collect
1408 1409 1410 1411 1412 1413 1414 1415 |
# File 'lib/rmagick_internal.rb', line 1408 def collect(&) current = get_current a = @images.map(&) ilist = self.class.new a.each { |image| ilist << image } ilist.set_current current ilist end |
#collect! ⇒ Object Also known as: map!, __map__!
1417 1418 1419 1420 1421 |
# File 'lib/rmagick_internal.rb', line 1417 def collect!(&) @images.map!(&) assert_image_array @images self end |
#combine ⇒ Magick::Image #combine(colorspace) ⇒ Magick::Image
Combines the images using the specified colorspace.
239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 |
# File 'ext/RMagick/rmilist.cpp', line 239
VALUE ImageList_combine(int argc, VALUE *argv, VALUE self)
{
#if defined(IMAGEMAGICK_6)
ChannelType channel;
ColorspaceType old_colorspace;
#endif
ColorspaceType colorspace;
long len;
Image *images, *new_image;
ExceptionInfo *exception;
len = check_imagelist_length(self);
switch (argc)
{
case 1:
VALUE_TO_ENUM(argv[0], colorspace, ColorspaceType);
break;
case 0:
colorspace = sRGBColorspace;
break;
default:
rb_raise(rb_eArgError, "wrong number of arguments (expected 1, got %d)", argc);
break;
}
#if defined(IMAGEMAGICK_7)
if (len > 5)
{
rb_raise(rb_eArgError, "invalid number of images in this image list");
}
if (len == 5 && colorspace != CMYKColorspace)
{
rb_raise(rb_eArgError, "invalid number of images in this image list");
}
#else
channel = RedChannel;
switch (len)
{
case 5:
if (colorspace == CMYKColorspace)
channel = (ChannelType)(channel | AlphaChannel);
else
rb_raise(rb_eArgError, "invalid number of images in this image list");
case 4:
if (colorspace == CMYKColorspace)
channel = (ChannelType)(channel | IndexChannel);
else
channel = (ChannelType)(channel | AlphaChannel);
case 3:
channel = (ChannelType)(channel | GreenChannel);
channel = (ChannelType)(channel | BlueChannel);
break;
case 2:
channel = (ChannelType)(channel | AlphaChannel);
break;
case 1:
break;
default:
rb_raise(rb_eArgError, "invalid number of images in this image list");
break;
}
#endif
VALUE clones;
images = images_from_imagelist(self, &clones);
exception = AcquireExceptionInfo();
#if defined(IMAGEMAGICK_6)
old_colorspace = images->colorspace;
SetImageColorspace(images, colorspace);
GVL_STRUCT_TYPE(CombineImages) args = { images, channel, exception };
#else
GVL_STRUCT_TYPE(CombineImages) args = { images, colorspace, exception };
#endif
new_image = (Image *)CALL_FUNC_WITHOUT_GVL(GVL_FUNC(CombineImages), &args);
rm_split(images);
RB_GC_GUARD(clones);
#if defined(IMAGEMAGICK_6)
images->colorspace = old_colorspace;
#endif
rm_check_exception(exception, new_image, DestroyOnError);
DestroyExceptionInfo(exception);
return rm_image_new(new_image);
}
|
#compact ⇒ Object
1446 1447 1448 1449 1450 1451 1452 1453 |
# File 'lib/rmagick_internal.rb', line 1446 def compact current = get_current ilist = self.class.new a = @images.compact a.each { |image| ilist << image } ilist.set_current current ilist end |
#compact! ⇒ Object
1455 1456 1457 1458 1459 1460 |
# File 'lib/rmagick_internal.rb', line 1455 def compact! current = get_current a = @images.compact! # returns nil if no changes were made set_current current a.nil? ? nil : self end |
#composite_layers(images) ⇒ Magick::ImageList #composite_layers(images, composite_op) ⇒ Magick::ImageList
An image from source images is composited over an image from receiver's list until one list is finished.
340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 |
# File 'ext/RMagick/rmilist.cpp', line 340
VALUE
ImageList_composite_layers(int argc, VALUE *argv, VALUE self)
{
VALUE source_images;
Image *dest, *source, *new_images;
RectangleInfo geometry;
CompositeOperator composite_op = OverCompositeOp;
ExceptionInfo *exception;
switch (argc)
{
case 2:
VALUE_TO_ENUM(argv[1], composite_op, CompositeOperator);
case 1:
source_images = argv[0];
break;
default:
rb_raise(rb_eArgError, "wrong number of arguments (expected 1 or 2, got %d)", argc);
break;
}
// Convert ImageLists to image sequences.
VALUE clones, source_clones = Qnil;
dest = images_from_imagelist(self, &clones);
new_images = clone_imagelist(dest);
rm_split(dest);
RB_GC_GUARD(clones);
// new_images is not owned by any Ruby object yet, so resolving the source
// list has to be able to unwind without abandoning it.
struct ImagesFromImageList_Args source_args = { source_images, &source_clones, NULL };
int state = 0;
rb_protect(images_from_imagelist_protected, (VALUE)&source_args, &state);
if (state)
{
DestroyImageList(new_images);
rb_jump_tag(state);
}
source = source_args.images;
SetGeometry(new_images, &geometry);
ParseAbsoluteGeometry(new_images->geometry, &geometry);
geometry.width = source->page.width != 0 ? source->page.width : source->columns;
geometry.height = source->page.height != 0 ? source->page.height : source->rows;
GravityAdjustGeometry(new_images->page.width != 0 ? new_images->page.width : new_images->columns,
new_images->page.height != 0 ? new_images->page.height : new_images->rows,
new_images->gravity, &geometry);
exception = AcquireExceptionInfo();
GVL_STRUCT_TYPE(CompositeLayers) args = { new_images, composite_op, source, geometry.x, geometry.y, exception };
CALL_FUNC_WITHOUT_GVL(GVL_FUNC(CompositeLayers), &args);
rm_split(source);
RB_GC_GUARD(source_clones);
rm_check_exception(exception, new_images, DestroyOnError);
DestroyExceptionInfo(exception);
RB_GC_GUARD(source_images);
return rm_imagelist_from_images(new_images);
}
|
#concat(other) ⇒ Object
1462 1463 1464 1465 1466 1467 |
# File 'lib/rmagick_internal.rb', line 1462 def concat(other) assert_image_array other other.each { |image| @images << image } @scene = length - 1 self end |
#copy ⇒ Object
Make a deep copy
1424 1425 1426 1427 1428 1429 |
# File 'lib/rmagick_internal.rb', line 1424 def copy ditto = self.class.new @images.each { |f| ditto << f.copy } ditto.scene = @scene ditto end |
#cur_image ⇒ Object
Return the current image
1432 1433 1434 1435 |
# File 'lib/rmagick_internal.rb', line 1432 def cur_image Kernel.raise IndexError, 'no images in this list' unless @scene @images[@scene] end |
#deconstruct ⇒ Magick::ImageList
Compare each image with the next in a sequence and returns the maximum bounding region of any pixel differences it discovers.
409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 |
# File 'ext/RMagick/rmilist.cpp', line 409
VALUE
ImageList_deconstruct(VALUE self)
{
Image *new_images, *images;
ExceptionInfo *exception;
VALUE clones;
images = images_from_imagelist(self, &clones);
exception = AcquireExceptionInfo();
#if defined(IMAGEMAGICK_7)
GVL_STRUCT_TYPE(CompareImagesLayers) args = { images, CompareAnyLayer, exception };
new_images = (Image *)CALL_FUNC_WITHOUT_GVL(GVL_FUNC(CompareImagesLayers), &args);
#else
GVL_STRUCT_TYPE(DeconstructImages) args = { images, exception };
new_images = (Image *)CALL_FUNC_WITHOUT_GVL(GVL_FUNC(DeconstructImages), &args);
#endif
rm_split(images);
RB_GC_GUARD(clones);
rm_check_exception(exception, new_images, DestroyOnError);
DestroyExceptionInfo(exception);
return rm_imagelist_from_images(new_images);
}
|
#delay=(d) ⇒ Object
Set same delay for all images
1470 1471 1472 1473 1474 |
# File 'lib/rmagick_internal.rb', line 1470 def delay=(d) raise ArgumentError, 'delay must be greater than or equal to 0' if Integer(d) < 0 @images.each { |f| f.delay = Integer(d) } end |
#delete(obj) ⇒ Object
1476 1477 1478 1479 1480 1481 1482 |
# File 'lib/rmagick_internal.rb', line 1476 def delete(obj, &) assert_image obj current = get_current a = @images.delete(obj, &) set_current current a end |
#delete_at(ndx) ⇒ Object
1484 1485 1486 1487 1488 1489 |
# File 'lib/rmagick_internal.rb', line 1484 def delete_at(ndx) current = get_current a = @images.delete_at(ndx) set_current current a end |
#delete_if ⇒ Object
1491 1492 1493 1494 1495 1496 |
# File 'lib/rmagick_internal.rb', line 1491 def delete_if(&) current = get_current @images.delete_if(&) set_current current self end |
#destroy! ⇒ Object
1809 1810 1811 1812 |
# File 'lib/rmagick_internal.rb', line 1809 def destroy! @images.each(&:destroy!) self end |
#destroyed? ⇒ Boolean
1814 1815 1816 |
# File 'lib/rmagick_internal.rb', line 1814 def destroyed? @images.all?(&:destroyed?) end |
#display {|info| ... } ⇒ Magick::ImageList Also known as: __display__
Display all the images to an X window screen.
441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 |
# File 'ext/RMagick/rmilist.cpp', line 441
VALUE
ImageList_display(VALUE self)
{
Image *images;
Info *info;
VALUE info_obj;
#if defined(IMAGEMAGICK_7)
ExceptionInfo *exception;
#endif
// Create a new Info object to use with this call
info_obj = rm_info_new();
TypedData_Get_Struct(info_obj, Info, &rm_info_data_type, info);
// Convert the images array to an images sequence.
VALUE clones;
images = images_from_imagelist(self, &clones);
#if defined(IMAGEMAGICK_7)
exception = AcquireExceptionInfo();
DisplayImages(info, images, exception);
rm_split(images);
CHECK_EXCEPTION();
DestroyExceptionInfo(exception);
#else
DisplayImages(info, images);
rm_split(images);
rm_check_image_exception(images, RetainOnError);
#endif
RB_GC_GUARD(clones);
RB_GC_GUARD(info_obj);
return self;
}
|
#dup ⇒ Object
1498 1499 1500 1501 1502 1503 |
# File 'lib/rmagick_internal.rb', line 1498 def dup ditto = self.class.new @images.each { |img| ditto << img } ditto.scene = @scene ditto end |
#eql?(other) ⇒ Boolean
1505 1506 1507 1508 1509 1510 1511 1512 1513 1514 1515 1516 1517 1518 1519 |
# File 'lib/rmagick_internal.rb', line 1505 def eql?(other) begin assert_image_array other rescue ArgumentError return false end eql = other.eql?(@images) begin # "other" is another ImageList eql &&= @scene == other.scene rescue NoMethodError # "other" is a plain Array end eql end |
#fill(*args, &block) ⇒ Object
1521 1522 1523 1524 1525 1526 1527 1528 |
# File 'lib/rmagick_internal.rb', line 1521 def fill(*args, &block) assert_image args[0] unless block current = get_current @images.fill(*args, &block) assert_image_array self set_current current self end |
#find_all ⇒ Object Also known as: select
Override Enumerable's find_all
1531 1532 1533 1534 1535 1536 1537 1538 |
# File 'lib/rmagick_internal.rb', line 1531 def find_all(&) current = get_current a = @images.select(&) ilist = self.class.new a.each { |image| ilist << image } ilist.set_current current ilist end |
#flatten_images ⇒ Magick::ImageList
Merge all the images into a single image.
482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 |
# File 'ext/RMagick/rmilist.cpp', line 482
VALUE
ImageList_flatten_images(VALUE self)
{
Image *images, *new_image;
ExceptionInfo *exception;
VALUE clones;
images = images_from_imagelist(self, &clones);
exception = AcquireExceptionInfo();
GVL_STRUCT_TYPE(MergeImageLayers) args = { images, FlattenLayer, exception };
new_image = (Image *)CALL_FUNC_WITHOUT_GVL(GVL_FUNC(MergeImageLayers), &args);
rm_split(images);
RB_GC_GUARD(clones);
rm_check_exception(exception, new_image, DestroyOnError);
DestroyExceptionInfo(exception);
return rm_image_new(new_image);
}
|
#from_blob(*blobs, &block) ⇒ Object
1541 1542 1543 1544 1545 1546 1547 1548 |
# File 'lib/rmagick_internal.rb', line 1541 def from_blob(*blobs, &block) Kernel.raise ArgumentError, 'no blobs given' if blobs.empty? blobs.each do |b| Magick::Image.from_blob(b, &block).each { |n| @images << n } end @scene = length - 1 self end |
#insert(index, *args) ⇒ Object
1561 1562 1563 1564 1565 1566 1567 |
# File 'lib/rmagick_internal.rb', line 1561 def insert(index, *args) args.each { |image| assert_image image } current = get_current @images.insert(index, *args) set_current current self end |
#inspect ⇒ Object
Call inspect for all the images
1570 1571 1572 1573 |
# File 'lib/rmagick_internal.rb', line 1570 def inspect img = @images.map(&:inspect) '[' + img.join(",\n") + "]\nscene=#{@scene}" end |
#iterations=(n) ⇒ Object
Set the number of iterations of an animated GIF
1576 1577 1578 1579 1580 |
# File 'lib/rmagick_internal.rb', line 1576 def iterations=(n) n = Integer(n) Kernel.raise ArgumentError, 'iterations must be between 0 and 65535' if n < 0 || n > 65_535 @images.each { |f| f.iterations = n } end |
#last(*args) ⇒ Object
1582 1583 1584 1585 1586 1587 1588 1589 1590 1591 1592 1593 |
# File 'lib/rmagick_internal.rb', line 1582 def last(*args) if args.empty? a = @images.last else a = @images.last(*args) ilist = self.class.new a.each { |img| ilist << img } @scene = a.length - 1 a = ilist end a end |
#marshal_dump ⇒ Object
Custom marshal/unmarshal for Ruby 1.8.
1596 1597 1598 1599 1600 |
# File 'lib/rmagick_internal.rb', line 1596 def marshal_dump ary = [@scene] @images.each { |i| ary << Marshal.dump(i) } ary end |
#marshal_load(ary) ⇒ Object
1602 1603 1604 1605 1606 |
# File 'lib/rmagick_internal.rb', line 1602 def marshal_load(ary) @scene = ary.shift @images = [] ary.each { |a| @images << Marshal.load(a) } # rubocop:disable Security/MarshalLoad end |
#montage ⇒ Magick::ImageList #montage {|opt| ... } ⇒ Magick::ImageList
Tile one or more thumbnails across an image canvas.
517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 |
# File 'ext/RMagick/rmilist.cpp', line 517
VALUE
ImageList_montage(VALUE self)
{
VALUE montage_obj;
Montage *montage;
Image *new_images, *images;
ExceptionInfo *exception;
// Create a new instance of the Magick::ImageList::Montage class
montage_obj = rm_montage_new();
if (rb_block_given_p())
{
rb_yield(montage_obj);
}
TypedData_Get_Struct(montage_obj, Montage, &rm_montage_data_type, montage);
VALUE clones;
images = images_from_imagelist(self, &clones);
for (Image *image = images; image; image = GetNextImageInList(image))
{
if (montage->compose != UndefinedCompositeOp)
{
image->compose = montage->compose;
}
image->background_color = montage->info->background_color;
image->border_color = montage->info->border_color;
image->matte_color = montage->info->matte_color;
image->gravity = montage->info->gravity;
}
exception = AcquireExceptionInfo();
// MontageImage can return more than one image.
GVL_STRUCT_TYPE(MontageImages) args = { images, montage->info, exception };
new_images = (Image *)CALL_FUNC_WITHOUT_GVL(GVL_FUNC(MontageImages), &args);
rm_split(images);
RB_GC_GUARD(clones);
rm_check_exception(exception, new_images, DestroyOnError);
DestroyExceptionInfo(exception);
RB_GC_GUARD(montage_obj);
return rm_imagelist_from_images(new_images);
}
|
#morph(nimages) ⇒ Magick::ImageList
Sets @scenes to 0
Requires a minimum of two images. The first image is transformed into the second by a number of intervening images as specified by "nimages".
573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 |
# File 'ext/RMagick/rmilist.cpp', line 573
VALUE
ImageList_morph(VALUE self, VALUE nimages)
{
Image *images, *new_images;
ExceptionInfo *exception;
size_t number_images;
// Use a signed long so we can test for a negative argument.
if (NUM2LONG(nimages) <= 0)
{
rb_raise(rb_eArgError, "number of intervening images must be > 0");
}
number_images = NUM2LONG(nimages);
VALUE clones;
images = images_from_imagelist(self, &clones);
exception = AcquireExceptionInfo();
GVL_STRUCT_TYPE(MorphImages) args = { images, number_images, exception };
new_images = (Image *)CALL_FUNC_WITHOUT_GVL(GVL_FUNC(MorphImages), &args);
rm_split(images);
RB_GC_GUARD(clones);
rm_check_exception(exception, new_images, DestroyOnError);
DestroyExceptionInfo(exception);
return rm_imagelist_from_images(new_images);
}
|
#mosaic ⇒ Magick::Image
Merge all the images into a single image.
607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 |
# File 'ext/RMagick/rmilist.cpp', line 607
VALUE
ImageList_mosaic(VALUE self)
{
Image *images, *new_image;
ExceptionInfo *exception;
VALUE clones;
images = images_from_imagelist(self, &clones);
exception = AcquireExceptionInfo();
GVL_STRUCT_TYPE(MergeImageLayers) args = { images, MosaicLayer, exception };
new_image = (Image *)CALL_FUNC_WITHOUT_GVL(GVL_FUNC(MergeImageLayers), &args);
rm_split(images);
RB_GC_GUARD(clones);
rm_check_exception(exception, new_image, DestroyOnError);
DestroyExceptionInfo(exception);
return rm_image_new(new_image);
}
|
#new_image(cols, rows, *fill) ⇒ Object
Create a new image and add it to the end
1628 1629 1630 |
# File 'lib/rmagick_internal.rb', line 1628 def new_image(cols, rows, *fill, &) self << Magick::Image.new(cols, rows, *fill, &) end |
#optimize_layers(method) ⇒ Magick::ImageList
Optimizes or compares the images in the list. Equivalent to the -layers option in ImageMagick's mogrify command.
636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 |
# File 'ext/RMagick/rmilist.cpp', line 636
VALUE
ImageList_optimize_layers(VALUE self, VALUE method)
{
Image *images, *new_images, *new_images2;
LayerMethod mthd;
ExceptionInfo *exception;
QuantizeInfo quantize_info;
new_images2 = NULL; // defeat "unused variable" message
VALUE_TO_ENUM(method, mthd, LayerMethod);
VALUE clones;
images = images_from_imagelist(self, &clones);
exception = AcquireExceptionInfo();
switch (mthd)
{
case CoalesceLayer:
{
GVL_STRUCT_TYPE(CoalesceImages) args = { images, exception };
new_images = (Image *)CALL_FUNC_WITHOUT_GVL(GVL_FUNC(CoalesceImages), &args);
}
break;
case DisposeLayer:
{
GVL_STRUCT_TYPE(DisposeImages) args = { images, exception };
new_images = (Image *)CALL_FUNC_WITHOUT_GVL(GVL_FUNC(DisposeImages), &args);
}
break;
case OptimizeTransLayer:
{
new_images = clone_imagelist(images);
GVL_STRUCT_TYPE(OptimizeImageTransparency) args = { new_images, exception };
CALL_FUNC_WITHOUT_GVL(GVL_FUNC(OptimizeImageTransparency), &args);
}
break;
case RemoveDupsLayer:
{
new_images = clone_imagelist(images);
GVL_STRUCT_TYPE(RemoveDuplicateLayers) args = { &new_images, exception };
CALL_FUNC_WITHOUT_GVL(GVL_FUNC(RemoveDuplicateLayers), &args);
}
break;
case RemoveZeroLayer:
{
new_images = clone_imagelist(images);
GVL_STRUCT_TYPE(RemoveZeroDelayLayers) args = { &new_images, exception };
CALL_FUNC_WITHOUT_GVL(GVL_FUNC(RemoveZeroDelayLayers), &args);
}
break;
case CompositeLayer:
rm_split(images);
DestroyExceptionInfo(exception);
rb_raise(rb_eNotImpError, "Magick::CompositeLayer is not supported. Use the composite_layers method instead.");
break;
// In 6.3.4-ish, OptimizeImageLayer replaced OptimizeLayer
case OptimizeImageLayer:
{
GVL_STRUCT_TYPE(OptimizeImageLayers) args = { images, exception };
new_images = (Image *)CALL_FUNC_WITHOUT_GVL(GVL_FUNC(OptimizeImageLayers), &args);
}
break;
// and OptimizeLayer became a "General Purpose, GIF Animation Optimizer" (ref. mogrify.c)
case OptimizeLayer:
{
GVL_STRUCT_TYPE(CoalesceImages) args_CoalesceImages = { images, exception };
new_images = (Image *)CALL_FUNC_WITHOUT_GVL(GVL_FUNC(CoalesceImages), &args_CoalesceImages);
rm_split(images);
rm_check_exception(exception, new_images, DestroyOnError);
GVL_STRUCT_TYPE(OptimizeImageLayers) args_OptimizeImageLayers = { new_images, exception };
new_images2 = (Image *)CALL_FUNC_WITHOUT_GVL(GVL_FUNC(OptimizeImageLayers), &args_OptimizeImageLayers);
DestroyImageList(new_images);
rm_check_exception(exception, new_images2, DestroyOnError);
new_images = new_images2;
GVL_STRUCT_TYPE(OptimizeImageTransparency) args_OptimizeImageTransparency = { new_images, exception };
CALL_FUNC_WITHOUT_GVL(GVL_FUNC(OptimizeImageTransparency), &args_OptimizeImageTransparency);
rm_check_exception(exception, new_images, DestroyOnError);
// mogrify supports -dither here. We don't.
GetQuantizeInfo(&quantize_info);
#if defined(IMAGEMAGICK_7)
GVL_STRUCT_TYPE(RemapImages) args_RemapImages = { &quantize_info, new_images, NULL, exception };
#else
GVL_STRUCT_TYPE(RemapImages) args_RemapImages = { &quantize_info, new_images, NULL };
#endif
CALL_FUNC_WITHOUT_GVL(GVL_FUNC(RemapImages), &args_RemapImages);
}
break;
case OptimizePlusLayer:
{
GVL_STRUCT_TYPE(OptimizePlusImageLayers) args = { images, exception };
new_images = (Image *)CALL_FUNC_WITHOUT_GVL(GVL_FUNC(OptimizePlusImageLayers), &args);
}
break;
case CompareAnyLayer:
case CompareClearLayer:
case CompareOverlayLayer:
{
#if defined(IMAGEMAGICK_7)
GVL_STRUCT_TYPE(CompareImagesLayers) args = { images, mthd, exception };
new_images = (Image *)CALL_FUNC_WITHOUT_GVL(GVL_FUNC(CompareImagesLayers), &args);
#else
GVL_STRUCT_TYPE(CompareImageLayers) args = { images, mthd, exception };
new_images = (Image *)CALL_FUNC_WITHOUT_GVL(GVL_FUNC(CompareImageLayers), &args);
#endif
}
break;
case MosaicLayer:
{
GVL_STRUCT_TYPE(MergeImageLayers) args = { images, mthd, exception };
new_images = (Image *)CALL_FUNC_WITHOUT_GVL(GVL_FUNC(MergeImageLayers), &args);
}
break;
case FlattenLayer:
{
GVL_STRUCT_TYPE(MergeImageLayers) args = { images, mthd, exception };
new_images = (Image *)CALL_FUNC_WITHOUT_GVL(GVL_FUNC(MergeImageLayers), &args);
}
break;
case MergeLayer:
{
GVL_STRUCT_TYPE(MergeImageLayers) args = { images, mthd, exception };
new_images = (Image *)CALL_FUNC_WITHOUT_GVL(GVL_FUNC(MergeImageLayers), &args);
}
break;
case TrimBoundsLayer:
{
GVL_STRUCT_TYPE(MergeImageLayers) args = { images, mthd, exception };
new_images = (Image *)CALL_FUNC_WITHOUT_GVL(GVL_FUNC(MergeImageLayers), &args);
}
break;
default:
rm_split(images);
DestroyExceptionInfo(exception);
rb_raise(rb_eArgError, "undefined layer method");
break;
}
rm_split(images);
RB_GC_GUARD(clones);
rm_check_exception(exception, new_images, DestroyOnError);
DestroyExceptionInfo(exception);
return rm_imagelist_from_images(new_images);
}
|
#partition ⇒ Object
1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 |
# File 'lib/rmagick_internal.rb', line 1632 def partition(&) a = @images.partition(&) t = self.class.new a[0].each { |img| t << img } t.set_current nil f = self.class.new a[1].each { |img| f << img } f.set_current nil [t, f] end |
#ping(*files, &block) ⇒ Object
Ping files and concatenate the new images
1644 1645 1646 1647 1648 1649 1650 1651 |
# File 'lib/rmagick_internal.rb', line 1644 def ping(*files, &block) Kernel.raise ArgumentError, 'no files given' if files.empty? files.each do |f| Magick::Image.ping(f, &block).each { |n| @images << n } end @scene = length - 1 self end |
#pop ⇒ Object
1653 1654 1655 1656 1657 1658 |
# File 'lib/rmagick_internal.rb', line 1653 def pop current = get_current a = @images.pop # can return nil set_current current a end |
#push(*objs) ⇒ Object
1660 1661 1662 1663 1664 1665 1666 1667 |
# File 'lib/rmagick_internal.rb', line 1660 def push(*objs) objs.each do |image| assert_image image @images << image end @scene = length - 1 self end |
#quantize(number_colors = 256, colorspace = Magick::RGBColorspace, dither = true, tree_depth = 0, measure_error = false) ⇒ Magick::ImageList
Analyzes the colors within a set of reference images and chooses a fixed number of colors to represent the set. The goal of the algorithm is to minimize the difference between the input and output images while minimizing the processing time.
1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 |
# File 'ext/RMagick/rmilist.cpp', line 1015
VALUE
ImageList_quantize(int argc, VALUE *argv, VALUE self)
{
Image *images, *new_images;
Image *new_image;
QuantizeInfo quantize_info;
ExceptionInfo *exception;
VALUE new_imagelist, scene;
GetQuantizeInfo(&quantize_info);
switch (argc)
{
case 5:
quantize_info.measure_error = (MagickBooleanType) RTEST(argv[4]);
case 4:
quantize_info.tree_depth = (unsigned long)NUM2INT(argv[3]);
case 3:
#if defined(IMAGEMAGICK_7)
if (rb_obj_is_kind_of(argv[2], Class_DitherMethod))
{
VALUE_TO_ENUM(argv[2], quantize_info.dither_method, DitherMethod);
}
else
{
quantize_info.dither_method = RTEST(argv[2]) ? UndefinedDitherMethod : NoDitherMethod;
}
#else
if (rb_obj_is_kind_of(argv[2], Class_DitherMethod))
{
VALUE_TO_ENUM(argv[2], quantize_info.dither_method, DitherMethod);
quantize_info.dither = (MagickBooleanType)(quantize_info.dither_method != NoDitherMethod);
}
else
{
quantize_info.dither = (MagickBooleanType) RTEST(argv[2]);
}
#endif
case 2:
VALUE_TO_ENUM(argv[1], quantize_info.colorspace, ColorspaceType);
case 1:
quantize_info.number_colors = NUM2ULONG(argv[0]);
case 0:
break;
default:
rb_raise(rb_eArgError, "wrong number of arguments (%d for 0 to 5)", argc);
break;
}
// Convert image array to image sequence, clone image sequence.
VALUE clones;
images = images_from_imagelist(self, &clones);
exception = AcquireExceptionInfo();
GVL_STRUCT_TYPE(CloneImageList) args_CloneImageList = { images, exception };
new_images = (Image *)CALL_FUNC_WITHOUT_GVL(GVL_FUNC(CloneImageList), &args_CloneImageList);
rm_split(images);
RB_GC_GUARD(clones);
rm_check_exception(exception, new_images, DestroyOnError);
rm_ensure_result(new_images);
#if defined(IMAGEMAGICK_7)
GVL_STRUCT_TYPE(QuantizeImages) args_QuantizeImages = { &quantize_info, new_images, exception };
#else
GVL_STRUCT_TYPE(QuantizeImages) args_QuantizeImages = { &quantize_info, new_images };
#endif
CALL_FUNC_WITHOUT_GVL(GVL_FUNC(QuantizeImages), &args_QuantizeImages);
rm_check_exception(exception, new_images, DestroyOnError);
DestroyExceptionInfo(exception);
// Create new ImageList object, convert mapped image sequence to images,
// append to images array.
new_imagelist = ImageList_new();
while ((new_image = RemoveFirstImageFromList(&new_images)))
{
imagelist_push(new_imagelist, rm_image_new(new_image));
}
// Set @scene in new ImageList object to same value as in self.
scene = rb_iv_get(self, "@scene");
rb_iv_set(new_imagelist, "@scene", scene);
RB_GC_GUARD(new_imagelist);
RB_GC_GUARD(scene);
return new_imagelist;
}
|
#read(*files, &block) ⇒ Object
Read files and concatenate the new images
1670 1671 1672 1673 1674 1675 1676 1677 |
# File 'lib/rmagick_internal.rb', line 1670 def read(*files, &block) Kernel.raise ArgumentError, 'no files given' if files.empty? files.each do |f| Magick::Image.read(f, &block).each { |n| @images << n } end @scene = length - 1 self end |
#reject ⇒ Object
override Enumerable's reject
1680 1681 1682 1683 1684 1685 1686 1687 |
# File 'lib/rmagick_internal.rb', line 1680 def reject(&) current = get_current ilist = self.class.new a = @images.reject(&) a.each { |image| ilist << image } ilist.set_current current ilist end |
#reject! ⇒ Object
1689 1690 1691 1692 1693 1694 1695 |
# File 'lib/rmagick_internal.rb', line 1689 def reject!(&) current = get_current a = @images.reject!(&) @images = a unless a.nil? set_current current a.nil? ? nil : self end |
#remap(remap_image = nil, dither_method = Magick::RiemersmaDitherMethod) ⇒ Magick::ImageList Also known as: affinity
Reduce the colors used in the image list to the set of colors in remap_image.
1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 1151 1152 1153 1154 1155 1156 1157 1158 1159 1160 1161 1162 1163 1164 1165 |
# File 'ext/RMagick/rmilist.cpp', line 1115
VALUE
ImageList_remap(int argc, VALUE *argv, VALUE self)
{
Image *images, *remap_image = NULL;
QuantizeInfo quantize_info;
#if defined(IMAGEMAGICK_7)
ExceptionInfo *exception;
#endif
if (argc > 0 && argv[0] != Qnil)
{
VALUE t = rm_cur_image(argv[0]);
remap_image = rm_check_destroyed(t);
RB_GC_GUARD(t);
}
GetQuantizeInfo(&quantize_info);
if (argc > 1)
{
VALUE_TO_ENUM(argv[1], quantize_info.dither_method, DitherMethod);
#if defined(IMAGEMAGICK_6)
quantize_info.dither = MagickTrue;
#endif
}
if (argc > 2)
{
rb_raise(rb_eArgError, "wrong number of arguments (%d for 1 or 2)", argc);
}
VALUE clones;
images = images_from_imagelist(self, &clones);
#if defined(IMAGEMAGICK_7)
exception = AcquireExceptionInfo();
GVL_STRUCT_TYPE(RemapImages) args = { &quantize_info, images, remap_image, exception };
CALL_FUNC_WITHOUT_GVL(GVL_FUNC(RemapImages), &args);
rm_split(images);
CHECK_EXCEPTION();
DestroyExceptionInfo(exception);
#else
GVL_STRUCT_TYPE(RemapImages) args = { &quantize_info, images, remap_image };
CALL_FUNC_WITHOUT_GVL(GVL_FUNC(RemapImages), &args);
rm_split(images);
rm_check_image_exception(images, RetainOnError);
#endif
RB_GC_GUARD(clones);
return self;
}
|
#replace(other) ⇒ Object
1697 1698 1699 1700 1701 1702 1703 1704 1705 |
# File 'lib/rmagick_internal.rb', line 1697 def replace(other) assert_image_array other current = get_current @images.clear other.each { |image| @images << image } @scene = length.zero? ? nil : 0 set_current current self end |
#respond_to?(meth_id, priv = false) ⇒ Boolean
1709 1710 1711 1712 1713 1714 1715 1716 1717 |
# File 'lib/rmagick_internal.rb', line 1709 def respond_to?(meth_id, priv = false) return true if __respond_to__?(meth_id, priv) if @scene @images[@scene].respond_to?(meth_id, priv) else super end end |
#reverse ⇒ Object
1719 1720 1721 1722 1723 1724 1725 |
# File 'lib/rmagick_internal.rb', line 1719 def reverse current = get_current a = self.class.new @images.reverse_each { |image| a << image } a.set_current current a end |
#reverse! ⇒ Object
1727 1728 1729 1730 1731 1732 |
# File 'lib/rmagick_internal.rb', line 1727 def reverse! current = get_current @images.reverse! set_current current self end |
#reverse_each ⇒ Object
1734 1735 1736 1737 |
# File 'lib/rmagick_internal.rb', line 1734 def reverse_each(&) @images.reverse_each(&) self end |
#shift ⇒ Object
1739 1740 1741 1742 1743 1744 |
# File 'lib/rmagick_internal.rb', line 1739 def shift current = get_current a = @images.shift set_current current a end |
#slice(*args) ⇒ Object
1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 1759 |
# File 'lib/rmagick_internal.rb', line 1746 def slice(*args) slice = @images.slice(*args) if slice ilist = self.class.new if slice.respond_to?(:each) slice.each { |image| ilist << image } else ilist << slice end else ilist = nil end ilist end |
#slice!(*args) ⇒ Object
1761 1762 1763 1764 1765 1766 |
# File 'lib/rmagick_internal.rb', line 1761 def slice!(*args) current = get_current a = @images.slice!(*args) set_current current a end |
#sort!(*args) ⇒ Object
1391 1392 1393 1394 |
# File 'lib/rmagick_internal.rb', line 1391 def sort!(*args, &) @images.sort!(*args, &) self end |
#ticks_per_second=(t) ⇒ Object
1768 1769 1770 1771 |
# File 'lib/rmagick_internal.rb', line 1768 def ticks_per_second=(t) Kernel.raise ArgumentError, 'ticks_per_second must be greater than or equal to 0' if Integer(t) < 0 @images.each { |f| f.ticks_per_second = Integer(t) } end |
#to_a ⇒ Object
1773 1774 1775 |
# File 'lib/rmagick_internal.rb', line 1773 def to_a @images.map { |image| image } end |
#to_blob ⇒ String #to_blob {|info| ... } ⇒ String
Return the imagelist as a blob (a String).
1180 1181 1182 1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 1224 1225 1226 1227 1228 1229 1230 1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 |
# File 'ext/RMagick/rmilist.cpp', line 1180
VALUE
ImageList_to_blob(VALUE self)
{
Image *images, *image;
Info *info;
VALUE info_obj;
VALUE blob_str;
void *blob = NULL;
size_t length = 0;
ExceptionInfo *exception;
info_obj = rm_info_new();
TypedData_Get_Struct(info_obj, Info, &rm_info_data_type, info);
// Convert the images array to an images sequence.
VALUE clones;
images = images_from_imagelist(self, &clones);
exception = AcquireExceptionInfo();
SetImageInfo(info, MagickTrue, exception);
rm_check_exception(exception, images, RetainOnError);
if (*info->magick != '\0')
{
Image *img;
for (img = images; img; img = GetNextImageInList(img))
{
strlcpy(img->magick, info->magick, sizeof(img->magick));
}
}
for (image = images; image; image = GetNextImageInList(image))
{
rm_sync_image_options(image, info);
}
// Unconditionally request multi-images support. The worst that
// can happen is that there's only one image or the format
// doesn't support multi-image files.
info->adjoin = MagickTrue;
GVL_STRUCT_TYPE(ImagesToBlob) args = { info, images, &length, exception };
blob = CALL_FUNC_WITHOUT_GVL(GVL_FUNC(ImagesToBlob), &args);
if (blob && exception->severity >= ErrorException)
{
magick_free((void*)blob);
blob = NULL;
length = 0;
}
rm_split(images);
RB_GC_GUARD(clones);
CHECK_EXCEPTION();
DestroyExceptionInfo(exception);
if (length == 0 || !blob)
{
return Qnil;
}
blob_str = rb_str_new((const char *)blob, (long)length);
magick_free((void*)blob);
RB_GC_GUARD(info_obj);
RB_GC_GUARD(blob_str);
return blob_str;
}
|
#uniq ⇒ Object
1777 1778 1779 1780 1781 1782 1783 |
# File 'lib/rmagick_internal.rb', line 1777 def uniq current = get_current a = self.class.new @images.uniq.each { |image| a << image } a.set_current current a end |
#uniq!(*_args) ⇒ Object
1785 1786 1787 1788 1789 1790 |
# File 'lib/rmagick_internal.rb', line 1785 def uniq!(*_args) current = get_current a = @images.uniq! set_current current a.nil? ? nil : self end |
#unshift(obj) ⇒ Object
1793 1794 1795 1796 1797 1798 |
# File 'lib/rmagick_internal.rb', line 1793 def unshift(obj) assert_image obj @images.unshift(obj) @scene = 0 self end |
#values_at(*args) ⇒ Object Also known as: indexes, indices
1800 1801 1802 1803 1804 1805 |
# File 'lib/rmagick_internal.rb', line 1800 def values_at(*args) a = self.class.new @images.values_at(*args).each { |image| a << image } a.scene = a.length - 1 a end |
#write(file) {|info| ... } ⇒ Object
Write all the images to the specified file. If the file format supports multi-image files, and the 'images' array contains more than one image, then the images will be written as a single multi-image file. Otherwise each image will be written to a separate file.
1259 1260 1261 1262 1263 1264 1265 1266 1267 1268 1269 1270 1271 1272 1273 1274 1275 1276 1277 1278 1279 1280 1281 1282 1283 1284 1285 1286 1287 1288 1289 1290 1291 1292 1293 1294 1295 1296 1297 1298 1299 1300 1301 1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 1329 1330 1331 1332 1333 1334 1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 |
# File 'ext/RMagick/rmilist.cpp', line 1259
VALUE
ImageList_write(VALUE self, VALUE file)
{
Image *images, *img;
Info *info;
const MagickInfo *m;
VALUE info_obj;
unsigned long scene;
ExceptionInfo *exception;
info_obj = rm_info_new();
TypedData_Get_Struct(info_obj, Info, &rm_info_data_type, info);
if (TYPE(file) == T_FILE)
{
rb_io_t *fptr;
// Ensure file is open - raise error if not
GetOpenFile(file, fptr);
rb_io_check_writable(fptr);
add_format_prefix(info, rm_io_path(file));
#if defined(_WIN32) && !defined(IMAGEMAGICK_GREATER_THAN_EQUAL_7_1_2)
SetImageInfoFile(info, NULL);
#else
SetImageInfoFile(info, rb_io_stdio_file(fptr));
#endif
}
else
{
add_format_prefix(info, file);
SetImageInfoFile(info, NULL);
}
// Convert the images array to an images sequence.
VALUE clones;
images = images_from_imagelist(self, &clones);
// Copy the filename into each image. Set a scene number to be used if
// writing multiple files. (Ref: ImageMagick's utilities/convert.c
for (scene = 0, img = images; img; img = GetNextImageInList(img))
{
img->scene = scene++;
strlcpy(img->filename, info->filename, sizeof(img->filename));
}
// Find out if the format supports multi-images files.
exception = AcquireExceptionInfo();
SetImageInfo(info, MagickTrue, exception);
rm_check_exception(exception, images, RetainOnError);
m = GetMagickInfo(info->magick, exception);
rm_check_exception(exception, images, RetainOnError);
#if defined(IMAGEMAGICK_6)
DestroyExceptionInfo(exception);
#endif
// Tell WriteImage if we want a multi-images file.
if (imagelist_length(self) > 1L && m && GetMagickAdjoin(m))
{
info->adjoin = MagickTrue;
}
for (img = images; img; img = GetNextImageInList(img))
{
rm_sync_image_options(img, info);
#if defined(IMAGEMAGICK_7)
GVL_STRUCT_TYPE(WriteImage) args = { info, img, exception };
CALL_FUNC_WITHOUT_GVL(GVL_FUNC(WriteImage), &args);
rm_check_exception(exception, img, RetainOnError);
#else
GVL_STRUCT_TYPE(WriteImage) args = { info, img };
CALL_FUNC_WITHOUT_GVL(GVL_FUNC(WriteImage), &args);
// images will be split before raising an exception
rm_check_image_exception(images, RetainOnError);
#endif
if (info->adjoin)
{
break;
}
}
#if defined(IMAGEMAGICK_7)
DestroyExceptionInfo(exception);
#endif
rm_split(images);
RB_GC_GUARD(clones);
RB_GC_GUARD(info_obj);
return self;
}
|